"""
Tag enums.
"""
from composio.client.enums.base import TAGS_CACHE, TagData, _AnnotatedEnum, enum

@enum
class Tag(_AnnotatedEnum[TagData], path=TAGS_CACHE):
    """Tag object."""
    AFFINITY_AUTH: 'Tag'
    AFFINITY_COMPANIES: 'Tag'
    AFFINITY_IMPORTANT: 'Tag'
    AFFINITY_LISTS: 'Tag'
    AFFINITY_OPPORTUNITIES: 'Tag'
    AFFINITY_PERSONS: 'Tag'
    AGENCYZOOM_AUTHENTICATION: 'Tag'
    AGENCYZOOM_BUSINESS_CLASSIFICATIONS: 'Tag'
    AGENCYZOOM_CONFIGURATION_AND_SETTINGS: 'Tag'
    AGENCYZOOM_CONTACT_MANAGEMENT: 'Tag'
    AGENCYZOOM_CUSTOMER_MANAGEMENT: 'Tag'
    AGENCYZOOM_DEPARTMENT_AND_GROUPS: 'Tag'
    AGENCYZOOM_IMPORTANT: 'Tag'
    AGENCYZOOM_LEAD_MANAGEMENT: 'Tag'
    AGENCYZOOM_LIFE_AND_HEALTH_LEAD_MANAGEMENT: 'Tag'
    AGENCYZOOM_OPPORTUNITY_MANAGEMENT: 'Tag'
    AGENCYZOOM_PIPELINE: 'Tag'
    AGENCYZOOM_SERVICE_CENTER: 'Tag'
    AGENCYZOOM_TASK_MANAGEMENT: 'Tag'
    AGENCYZOOM_THREAD: 'Tag'
    AGENCYZOOM_USER_MANAGEMENT: 'Tag'
    AGENCYZOOM_V4SSO_AUTHENTICATION: 'Tag'
    AIRTABLE_IMPORTANT: 'Tag'
    ASANA_ALLOCATIONS: 'Tag'
    ASANA_ATTACHMENTS: 'Tag'
    ASANA_AUDIT_LOG_API: 'Tag'
    ASANA_BATCH_API: 'Tag'
    ASANA_CUSTOM_FIELDS: 'Tag'
    ASANA_CUSTOM_FIELD_SETTINGS: 'Tag'
    ASANA_EVENTS: 'Tag'
    ASANA_GOALS: 'Tag'
    ASANA_GOAL_RELATIONSHIPS: 'Tag'
    ASANA_IMPORTANT: 'Tag'
    ASANA_JOBS: 'Tag'
    ASANA_MEMBERSHIPS: 'Tag'
    ASANA_ORGANIZATION_EXPORTS: 'Tag'
    ASANA_PORTFOLIOS: 'Tag'
    ASANA_PORTFOLIO_MEMBERSHIPS: 'Tag'
    ASANA_PROJECTS: 'Tag'
    ASANA_PROJECT_BRIEFS: 'Tag'
    ASANA_PROJECT_MEMBERSHIPS: 'Tag'
    ASANA_PROJECT_STATUSES: 'Tag'
    ASANA_PROJECT_TEMPLATES: 'Tag'
    ASANA_RULES: 'Tag'
    ASANA_SECTIONS: 'Tag'
    ASANA_STATUS_UPDATES: 'Tag'
    ASANA_STORIES: 'Tag'
    ASANA_TAGS: 'Tag'
    ASANA_TASKS: 'Tag'
    ASANA_TASK_TEMPLATES: 'Tag'
    ASANA_TEAMS: 'Tag'
    ASANA_TEAM_MEMBERSHIPS: 'Tag'
    ASANA_TIME_PERIODS: 'Tag'
    ASANA_TIME_TRACKING_ENTRIES: 'Tag'
    ASANA_TYPEAHEAD: 'Tag'
    ASANA_USERS: 'Tag'
    ASANA_USER_TASK_LISTS: 'Tag'
    ASANA_WEBHOOKS: 'Tag'
    ASANA_WORKSPACES: 'Tag'
    ASANA_WORKSPACE_MEMBERSHIPS: 'Tag'
    ATTIO_ATTRIBUTES: 'Tag'
    ATTIO_COMMENTS: 'Tag'
    ATTIO_ENTRIES: 'Tag'
    ATTIO_IMPORTANT: 'Tag'
    ATTIO_LISTS: 'Tag'
    ATTIO_META: 'Tag'
    ATTIO_NOTES: 'Tag'
    ATTIO_OBJECTS: 'Tag'
    ATTIO_RECORDS: 'Tag'
    ATTIO_TASKS: 'Tag'
    ATTIO_THREADS: 'Tag'
    ATTIO_WEBHOOKS: 'Tag'
    ATTIO_WORKSPACE_MEMBERS: 'Tag'
    BAMBOOHR_ACCOUNT_INFORMATION: 'Tag'
    BAMBOOHR_APPLICANT_TRACKING: 'Tag'
    BAMBOOHR_BENEFITS: 'Tag'
    BAMBOOHR_COMPANY_FILES: 'Tag'
    BAMBOOHR_EMPLOYEES: 'Tag'
    BAMBOOHR_EMPLOYEE_FILES: 'Tag'
    BAMBOOHR_GOALS: 'Tag'
    BAMBOOHR_HOURS: 'Tag'
    BAMBOOHR_IMPORTANT: 'Tag'
    BAMBOOHR_LAST_CHANGE_INFORMATION: 'Tag'
    BAMBOOHR_LOGIN: 'Tag'
    BAMBOOHR_PAYROLL: 'Tag'
    BAMBOOHR_PHOTOS: 'Tag'
    BAMBOOHR_REPORTS: 'Tag'
    BAMBOOHR_TABULAR_DATA: 'Tag'
    BAMBOOHR_TIME_OFF: 'Tag'
    BAMBOOHR_TIME_TRACKING: 'Tag'
    BAMBOOHR_TIME_TRACKING___PRIVATE_BETA: 'Tag'
    BAMBOOHR_TRAINING: 'Tag'
    BAMBOOHR_WEBHOOKS: 'Tag'
    BITBUCKET_ADDON: 'Tag'
    BITBUCKET_BRANCHING_MODEL: 'Tag'
    BITBUCKET_BRANCH_RESTRICTIONS: 'Tag'
    BITBUCKET_COMMITS: 'Tag'
    BITBUCKET_COMMIT_STATUSES: 'Tag'
    BITBUCKET_DEPLOYMENTS: 'Tag'
    BITBUCKET_DOWNLOADS: 'Tag'
    BITBUCKET_IMPORTANT: 'Tag'
    BITBUCKET_ISSUE_TRACKER: 'Tag'
    BITBUCKET_PIPELINES: 'Tag'
    BITBUCKET_PROJECTS: 'Tag'
    BITBUCKET_PROPERTIES: 'Tag'
    BITBUCKET_PULLREQUESTS: 'Tag'
    BITBUCKET_REFS: 'Tag'
    BITBUCKET_REPORTS: 'Tag'
    BITBUCKET_REPOSITORIES: 'Tag'
    BITBUCKET_SEARCH: 'Tag'
    BITBUCKET_SNIPPETS: 'Tag'
    BITBUCKET_SOURCE: 'Tag'
    BITBUCKET_SSH: 'Tag'
    BITBUCKET_USERS: 'Tag'
    BITBUCKET_WEBHOOKS: 'Tag'
    BITBUCKET_WORKSPACES: 'Tag'
    BLACKBOARD_ADAPTIVE_RELEASE: 'Tag'
    BLACKBOARD_ANNOUNCEMENTS: 'Tag'
    BLACKBOARD_ATTEMPT_RECEIPT: 'Tag'
    BLACKBOARD_ATTENDANCE: 'Tag'
    BLACKBOARD_CALENDAR: 'Tag'
    BLACKBOARD_CONTENT: 'Tag'
    BLACKBOARD_CONTENT_COLLECTION_RESOURCES: 'Tag'
    BLACKBOARD_CONTENT_FILE_ATTACHMENTS: 'Tag'
    BLACKBOARD_CONTENT_GROUP_ASSIGNMENTS: 'Tag'
    BLACKBOARD_CONTENT_RESOURCES: 'Tag'
    BLACKBOARD_CONTENT_REVIEW: 'Tag'
    BLACKBOARD_COURSES: 'Tag'
    BLACKBOARD_COURSE_ANNOUNCEMENTS: 'Tag'
    BLACKBOARD_COURSE_ASSESSMENTS: 'Tag'
    BLACKBOARD_COURSE_CATEGORIES: 'Tag'
    BLACKBOARD_COURSE_GRADEBOOK_CATEGORIES: 'Tag'
    BLACKBOARD_COURSE_GRADES: 'Tag'
    BLACKBOARD_COURSE_GRADE_ATTEMPTS: 'Tag'
    BLACKBOARD_COURSE_GRADE_NOTATIONS: 'Tag'
    BLACKBOARD_COURSE_GRADING_PERIODS: 'Tag'
    BLACKBOARD_COURSE_GROUPS: 'Tag'
    BLACKBOARD_COURSE_GROUP_USERS: 'Tag'
    BLACKBOARD_COURSE_MEMBERSHIPS: 'Tag'
    BLACKBOARD_COURSE_MESSAGES: 'Tag'
    BLACKBOARD_COURSE_TOC: 'Tag'
    BLACKBOARD_DATA_SOURCES: 'Tag'
    BLACKBOARD_DEPRECATED___COURSES: 'Tag'
    BLACKBOARD_DEPRECATED___COURSE_GRADES: 'Tag'
    BLACKBOARD_DEPRECATED___COURSE_GROUPS: 'Tag'
    BLACKBOARD_DEPRECATED___COURSE_GROUP_USERS: 'Tag'
    BLACKBOARD_DISCUSSIONS: 'Tag'
    BLACKBOARD_GOALS: 'Tag'
    BLACKBOARD_IMPORTANT: 'Tag'
    BLACKBOARD_INSTITUTIONAL_HIERARCHY: 'Tag'
    BLACKBOARD_INSTITUTIONAL_HIERARCHY_ADMINISTRATORS: 'Tag'
    BLACKBOARD_LTI: 'Tag'
    BLACKBOARD_OAUTH: 'Tag'
    BLACKBOARD_PERFORMANCE_DASHBOARD: 'Tag'
    BLACKBOARD_PROCTORING: 'Tag'
    BLACKBOARD_PRONOUNS: 'Tag'
    BLACKBOARD_ROLES: 'Tag'
    BLACKBOARD_RUBRICS: 'Tag'
    BLACKBOARD_RUBRIC_ASSOCIATIONS: 'Tag'
    BLACKBOARD_RUBRIC_EVALUATIONS: 'Tag'
    BLACKBOARD_SESSIONS: 'Tag'
    BLACKBOARD_SIS_LOGS: 'Tag'
    BLACKBOARD_SYSTEM: 'Tag'
    BLACKBOARD_TERMS: 'Tag'
    BLACKBOARD_UPLOADS: 'Tag'
    BLACKBOARD_USERS: 'Tag'
    BREVO_ACCOUNT: 'Tag'
    BREVO_COMPANIES: 'Tag'
    BREVO_CONTACTS: 'Tag'
    BREVO_CONVERSATIONS: 'Tag'
    BREVO_COUPONS: 'Tag'
    BREVO_DEALS: 'Tag'
    BREVO_DOMAINS: 'Tag'
    BREVO_ECOMMERCE: 'Tag'
    BREVO_EMAIL_CAMPAIGNS: 'Tag'
    BREVO_EVENT: 'Tag'
    BREVO_EXTERNAL_FEEDS: 'Tag'
    BREVO_FILES: 'Tag'
    BREVO_IMPORTANT: 'Tag'
    BREVO_INBOUND_PARSING: 'Tag'
    BREVO_MASTER_ACCOUNT: 'Tag'
    BREVO_NOTES: 'Tag'
    BREVO_PROCESS: 'Tag'
    BREVO_RESELLER: 'Tag'
    BREVO_SENDERS: 'Tag'
    BREVO_SMS_CAMPAIGNS: 'Tag'
    BREVO_TASKS: 'Tag'
    BREVO_TRANSACTIONAL_EMAILS: 'Tag'
    BREVO_TRANSACTIONAL_SMS: 'Tag'
    BREVO_TRANSACTIONAL_WHATSAPP: 'Tag'
    BREVO_USER: 'Tag'
    BREVO_WEBHOOKS: 'Tag'
    BREVO_WHATSAPP_CAMPAIGNS: 'Tag'
    CALENDLY_ACTIVITY_LOG: 'Tag'
    CALENDLY_AVAILABILITY: 'Tag'
    CALENDLY_DATA_COMPLIANCE: 'Tag'
    CALENDLY_EVENT_TYPES: 'Tag'
    CALENDLY_GROUPS: 'Tag'
    CALENDLY_IMPORTANT: 'Tag'
    CALENDLY_ORGANIZATIONS: 'Tag'
    CALENDLY_OUTGOING_COMMUNICATIONS: 'Tag'
    CALENDLY_ROUTING_FORMS: 'Tag'
    CALENDLY_SCHEDULED_EVENTS: 'Tag'
    CALENDLY_SCHEDULING_LINKS: 'Tag'
    CALENDLY_SHARES: 'Tag'
    CALENDLY_USERS: 'Tag'
    CALENDLY_WEBHOOKS: 'Tag'
    CANVAS_ACCOUNTS: 'Tag'
    CANVAS_ANALYTICS: 'Tag'
    CANVAS_ASSIGNMENTS: 'Tag'
    CANVAS_CALENDAR: 'Tag'
    CANVAS_COMMUNICATIONCHANNELS: 'Tag'
    CANVAS_CONTENTEXPORTS: 'Tag'
    CANVAS_CONTENTSHARES: 'Tag'
    CANVAS_COURSES: 'Tag'
    CANVAS_ENROLLMENTS: 'Tag'
    CANVAS_ENROLLMENTTERMS: 'Tag'
    CANVAS_FILES: 'Tag'
    CANVAS_GRADEBOOK_HISTORY: 'Tag'
    CANVAS_IMPORTANT: 'Tag'
    CANVAS_PAGES: 'Tag'
    CANVAS_REPORTS: 'Tag'
    CANVAS_SUBMISSIONS: 'Tag'
    CANVAS_USERS: 'Tag'
    CANVA_APP: 'Tag'
    CANVA_ASSET: 'Tag'
    CANVA_AUTOFILL: 'Tag'
    CANVA_BRAND_TEMPLATE: 'Tag'
    CANVA_COMMENT: 'Tag'
    CANVA_CONNECT: 'Tag'
    CANVA_DESIGN: 'Tag'
    CANVA_DESIGN_IMPORT: 'Tag'
    CANVA_EXPORT: 'Tag'
    CANVA_FOLDER: 'Tag'
    CANVA_IMPORTANT: 'Tag'
    CANVA_OAUTH: 'Tag'
    CANVA_USER: 'Tag'
    CLICKUP_ATTACHMENTS: 'Tag'
    CLICKUP_AUTHORIZATION: 'Tag'
    CLICKUP_COMMENTS: 'Tag'
    CLICKUP_CUSTOM_FIELDS: 'Tag'
    CLICKUP_CUSTOM_TASK_TYPES: 'Tag'
    CLICKUP_FOLDERS: 'Tag'
    CLICKUP_GOALS: 'Tag'
    CLICKUP_GUESTS: 'Tag'
    CLICKUP_IMPORTANT: 'Tag'
    CLICKUP_LISTS: 'Tag'
    CLICKUP_MEMBERS: 'Tag'
    CLICKUP_ROLES: 'Tag'
    CLICKUP_SHARED_HIERARCHY: 'Tag'
    CLICKUP_SPACES: 'Tag'
    CLICKUP_TAGS: 'Tag'
    CLICKUP_TASKS: 'Tag'
    CLICKUP_TASK_CHECKLISTS: 'Tag'
    CLICKUP_TASK_RELATIONSHIPS: 'Tag'
    CLICKUP_TASK_TEMPLATES: 'Tag'
    CLICKUP_TEAMS___USER_GROUPS: 'Tag'
    CLICKUP_TEAMS___WORKSPACES: 'Tag'
    CLICKUP_TIME_TRACKING: 'Tag'
    CLICKUP_TIME_TRACKING__LEGACY_: 'Tag'
    CLICKUP_USERS: 'Tag'
    CLICKUP_VIEWS: 'Tag'
    CLICKUP_WEBHOOKS: 'Tag'
    DEFAULT: 'Tag'
    DISCORDBOT_IMPORTANT: 'Tag'
    DISCORD_IMPORTANT: 'Tag'
    DOCUSIGN_ACCOUNTBRANDS: 'Tag'
    DOCUSIGN_ACCOUNTCONSUMERDISCLOSURES: 'Tag'
    DOCUSIGN_ACCOUNTCUSTOMFIELDS: 'Tag'
    DOCUSIGN_ACCOUNTPASSWORDRULES: 'Tag'
    DOCUSIGN_ACCOUNTPERMISSIONPROFILES: 'Tag'
    DOCUSIGN_ACCOUNTS: 'Tag'
    DOCUSIGN_ACCOUNTSEALPROVIDERS: 'Tag'
    DOCUSIGN_ACCOUNTSIGNATUREPROVIDERS: 'Tag'
    DOCUSIGN_ACCOUNTSIGNATURES: 'Tag'
    DOCUSIGN_ACCOUNTTABSETTINGS: 'Tag'
    DOCUSIGN_ACCOUNTWATERMARKS: 'Tag'
    DOCUSIGN_AUTHORIZATIONS: 'Tag'
    DOCUSIGN_BCCEMAILARCHIVE: 'Tag'
    DOCUSIGN_BILLINGPLANS: 'Tag'
    DOCUSIGN_BULKSEND: 'Tag'
    DOCUSIGN_CHUNKEDUPLOADS: 'Tag'
    DOCUSIGN_CLOUDSTORAGE: 'Tag'
    DOCUSIGN_CLOUDSTORAGEPROVIDERS: 'Tag'
    DOCUSIGN_COMMENTS: 'Tag'
    DOCUSIGN_CONNECTCONFIGURATIONS: 'Tag'
    DOCUSIGN_CONNECTEVENTS: 'Tag'
    DOCUSIGN_CONTACTS: 'Tag'
    DOCUSIGN_CUSTOMTABS: 'Tag'
    DOCUSIGN_DOCUMENTRESPONSIVEHTMLPREVIEW: 'Tag'
    DOCUSIGN_ENOTECONFIGURATIONS: 'Tag'
    DOCUSIGN_ENVELOPEATTACHMENTS: 'Tag'
    DOCUSIGN_ENVELOPECONSUMERDISCLOSURES: 'Tag'
    DOCUSIGN_ENVELOPECUSTOMFIELDS: 'Tag'
    DOCUSIGN_ENVELOPEDOCUMENTFIELDS: 'Tag'
    DOCUSIGN_ENVELOPEDOCUMENTHTMLDEFINITIONS: 'Tag'
    DOCUSIGN_ENVELOPEDOCUMENTS: 'Tag'
    DOCUSIGN_ENVELOPEDOCUMENTVISIBILITY: 'Tag'
    DOCUSIGN_ENVELOPEEMAILSETTINGS: 'Tag'
    DOCUSIGN_ENVELOPEFORMDATA: 'Tag'
    DOCUSIGN_ENVELOPEHTMLDEFINITIONS: 'Tag'
    DOCUSIGN_ENVELOPELOCKS: 'Tag'
    DOCUSIGN_ENVELOPEPUBLISH: 'Tag'
    DOCUSIGN_ENVELOPERECIPIENTS: 'Tag'
    DOCUSIGN_ENVELOPES: 'Tag'
    DOCUSIGN_ENVELOPETEMPLATES: 'Tag'
    DOCUSIGN_ENVELOPETRANSFERRULES: 'Tag'
    DOCUSIGN_ENVELOPEVIEWS: 'Tag'
    DOCUSIGN_ENVELOPEWORKFLOWDEFINITION: 'Tag'
    DOCUSIGN_FAVORITETEMPLATES: 'Tag'
    DOCUSIGN_GROUPBRANDS: 'Tag'
    DOCUSIGN_GROUPS: 'Tag'
    DOCUSIGN_GROUPUSERS: 'Tag'
    DOCUSIGN_IDENTITYVERIFICATIONS: 'Tag'
    DOCUSIGN_IMPORTANT: 'Tag'
    DOCUSIGN_INVOICES: 'Tag'
    DOCUSIGN_NOTARY: 'Tag'
    DOCUSIGN_NOTARYJOURNALS: 'Tag'
    DOCUSIGN_NOTARYJURISDICTION: 'Tag'
    DOCUSIGN_PAYMENTGATEWAYACCOUNTS: 'Tag'
    DOCUSIGN_PAYMENTS: 'Tag'
    DOCUSIGN_POWERFORMDATA: 'Tag'
    DOCUSIGN_POWERFORMS: 'Tag'
    DOCUSIGN_REQUESTLOGS: 'Tag'
    DOCUSIGN_RESOURCES: 'Tag'
    DOCUSIGN_RESPONSIVEHTMLPREVIEW: 'Tag'
    DOCUSIGN_SERVICES: 'Tag'
    DOCUSIGN_SIGNINGGROUPS: 'Tag'
    DOCUSIGN_SIGNINGGROUPUSERS: 'Tag'
    DOCUSIGN_TABSBLOB: 'Tag'
    DOCUSIGN_TEMPLATECUSTOMFIELDS: 'Tag'
    DOCUSIGN_TEMPLATEDOCUMENTFIELDS: 'Tag'
    DOCUSIGN_TEMPLATEDOCUMENTHTMLDEFINITIONS: 'Tag'
    DOCUSIGN_TEMPLATEDOCUMENTRESPONSIVEHTMLPREVIEW: 'Tag'
    DOCUSIGN_TEMPLATEDOCUMENTS: 'Tag'
    DOCUSIGN_TEMPLATEDOCUMENTVISIBILITY: 'Tag'
    DOCUSIGN_TEMPLATEHTMLDEFINITIONS: 'Tag'
    DOCUSIGN_TEMPLATELOCKS: 'Tag'
    DOCUSIGN_TEMPLATERECIPIENTS: 'Tag'
    DOCUSIGN_TEMPLATERESPONSIVEHTMLPREVIEW: 'Tag'
    DOCUSIGN_TEMPLATES: 'Tag'
    DOCUSIGN_TEMPLATEVIEWS: 'Tag'
    DOCUSIGN_USERCUSTOMSETTINGS: 'Tag'
    DOCUSIGN_USERPROFILES: 'Tag'
    DOCUSIGN_USERS: 'Tag'
    DOCUSIGN_USERSIGNATURES: 'Tag'
    DOCUSIGN_WORKSPACEITEMS: 'Tag'
    DOCUSIGN_WORKSPACES: 'Tag'
    ELEVENLABS_AUDIO_NATIVE: 'Tag'
    ELEVENLABS_DUBBING: 'Tag'
    ELEVENLABS_IMPORTANT: 'Tag'
    ELEVENLABS_MODELS: 'Tag'
    ELEVENLABS_PROJECTS: 'Tag'
    ELEVENLABS_PRONUNCIATION_DICTIONARY: 'Tag'
    ELEVENLABS_SAMPLES: 'Tag'
    ELEVENLABS_SPEECH_HISTORY: 'Tag'
    ELEVENLABS_SPEECH_TO_SPEECH: 'Tag'
    ELEVENLABS_TEXT_TO_SPEECH: 'Tag'
    ELEVENLABS_USER: 'Tag'
    ELEVENLABS_VOICES: 'Tag'
    ELEVENLABS_VOICE_GENERATION: 'Tag'
    ELEVENLABS_WORKSPACE: 'Tag'
    FIGMA_ACTIVITY_LOGS: 'Tag'
    FIGMA_COMMENTS: 'Tag'
    FIGMA_COMMENT_REACTIONS: 'Tag'
    FIGMA_COMPONENTS: 'Tag'
    FIGMA_COMPONENT_SETS: 'Tag'
    FIGMA_DEV_RESOURCES: 'Tag'
    FIGMA_FILES: 'Tag'
    FIGMA_IMPORTANT: 'Tag'
    FIGMA_PAYMENTS: 'Tag'
    FIGMA_PROJECTS: 'Tag'
    FIGMA_STYLES: 'Tag'
    FIGMA_USERS: 'Tag'
    FIGMA_VARIABLES: 'Tag'
    FIGMA_WEBHOOKS: 'Tag'
    GITHUB_ACTIONS: 'Tag'
    GITHUB_ACTIVITY: 'Tag'
    GITHUB_APPS: 'Tag'
    GITHUB_BILLING: 'Tag'
    GITHUB_CHECKS: 'Tag'
    GITHUB_CLASSROOM: 'Tag'
    GITHUB_CODESPACES: 'Tag'
    GITHUB_CODES_OF_CONDUCT: 'Tag'
    GITHUB_CODE_SCANNING: 'Tag'
    GITHUB_COPILOT: 'Tag'
    GITHUB_DEPENDABOT: 'Tag'
    GITHUB_DEPENDENCY_GRAPH: 'Tag'
    GITHUB_EMOJIS: 'Tag'
    GITHUB_GISTS: 'Tag'
    GITHUB_GIT: 'Tag'
    GITHUB_GITIGNORE: 'Tag'
    GITHUB_IMPORTANT: 'Tag'
    GITHUB_INTERACTIONS: 'Tag'
    GITHUB_ISSUES: 'Tag'
    GITHUB_LICENSES: 'Tag'
    GITHUB_MARKDOWN: 'Tag'
    GITHUB_META: 'Tag'
    GITHUB_MIGRATIONS: 'Tag'
    GITHUB_OIDC: 'Tag'
    GITHUB_ORGS: 'Tag'
    GITHUB_PACKAGES: 'Tag'
    GITHUB_PROJECTS: 'Tag'
    GITHUB_PULLS: 'Tag'
    GITHUB_RATE_LIMIT: 'Tag'
    GITHUB_REACTIONS: 'Tag'
    GITHUB_REPOS: 'Tag'
    GITHUB_SEARCH: 'Tag'
    GITHUB_SECRET_SCANNING: 'Tag'
    GITHUB_SECURITY_ADVISORIES: 'Tag'
    GITHUB_TEAMS: 'Tag'
    GITHUB_USERS: 'Tag'
    HEYGEN_CREATE_VIDEO_API: 'Tag'
    HEYGEN_DEFAULT: 'Tag'
    HEYGEN_IMPORTANT: 'Tag'
    HEYGEN_LISTS: 'Tag'
    HEYGEN_PERSONALIZED_VIDEO: 'Tag'
    HEYGEN_STREAMING_API: 'Tag'
    HEYGEN_TALKING_PHOTO: 'Tag'
    HEYGEN_TEMPLATE_API: 'Tag'
    HEYGEN_USER: 'Tag'
    HEYGEN_VIDEO_TRANSLATE_API: 'Tag'
    HEYGEN_WEBHOOKS: 'Tag'
    HUBSPOT_BASIC: 'Tag'
    HUBSPOT_BATCH: 'Tag'
    HUBSPOT_CORE: 'Tag'
    HUBSPOT_EVENTS: 'Tag'
    HUBSPOT_GDPR: 'Tag'
    HUBSPOT_GROUPS: 'Tag'
    HUBSPOT_IMPORTANT: 'Tag'
    HUBSPOT_OWNERS: 'Tag'
    HUBSPOT_PIPELINES: 'Tag'
    HUBSPOT_PIPELINE_AUDITS: 'Tag'
    HUBSPOT_PIPELINE_STAGES: 'Tag'
    HUBSPOT_PIPELINE_STAGE_AUDITS: 'Tag'
    HUBSPOT_PUBLIC_IMPORTS: 'Tag'
    HUBSPOT_PUBLIC_OBJECT: 'Tag'
    HUBSPOT_PUBLIC_OBJECT_SCHEMAS: 'Tag'
    HUBSPOT_RECORDING_SETTINGS: 'Tag'
    HUBSPOT_SEARCH: 'Tag'
    HUBSPOT_SETTINGS: 'Tag'
    HUBSPOT_TEMPLATES: 'Tag'
    HUBSPOT_TOKENS: 'Tag'
    HUBSPOT_TYPES: 'Tag'
    JIRA_ANNOUNCEMENT_BANNER: 'Tag'
    JIRA_APPLICATION_ROLES: 'Tag'
    JIRA_APP_DATA_POLICIES__EAP_: 'Tag'
    JIRA_APP_MIGRATION: 'Tag'
    JIRA_APP_PROPERTIES: 'Tag'
    JIRA_AUDIT_RECORDS: 'Tag'
    JIRA_AVATARS: 'Tag'
    JIRA_CLASSIFICATION_LEVELS: 'Tag'
    JIRA_DASHBOARDS: 'Tag'
    JIRA_DYNAMIC_MODULES: 'Tag'
    JIRA_FILTERS: 'Tag'
    JIRA_FILTER_SHARING: 'Tag'
    JIRA_GROUPS: 'Tag'
    JIRA_GROUP_AND_USER_PICKER: 'Tag'
    JIRA_IMPORTANT: 'Tag'
    JIRA_ISSUES: 'Tag'
    JIRA_ISSUE_ATTACHMENTS: 'Tag'
    JIRA_ISSUE_COMMENTS: 'Tag'
    JIRA_ISSUE_COMMENT_PROPERTIES: 'Tag'
    JIRA_ISSUE_CUSTOM_FIELD_CONFIGURATION__APPS_: 'Tag'
    JIRA_ISSUE_CUSTOM_FIELD_CONTEXTS: 'Tag'
    JIRA_ISSUE_CUSTOM_FIELD_OPTIONS: 'Tag'
    JIRA_ISSUE_CUSTOM_FIELD_OPTIONS__APPS_: 'Tag'
    JIRA_ISSUE_CUSTOM_FIELD_VALUES__APPS_: 'Tag'
    JIRA_ISSUE_FIELDS: 'Tag'
    JIRA_ISSUE_FIELD_CONFIGURATIONS: 'Tag'
    JIRA_ISSUE_LINKS: 'Tag'
    JIRA_ISSUE_LINK_TYPES: 'Tag'
    JIRA_ISSUE_NAVIGATOR_SETTINGS: 'Tag'
    JIRA_ISSUE_NOTIFICATION_SCHEMES: 'Tag'
    JIRA_ISSUE_PRIORITIES: 'Tag'
    JIRA_ISSUE_PROPERTIES: 'Tag'
    JIRA_ISSUE_REMOTE_LINKS: 'Tag'
    JIRA_ISSUE_RESOLUTIONS: 'Tag'
    JIRA_ISSUE_SEARCH: 'Tag'
    JIRA_ISSUE_SECURITY_LEVEL: 'Tag'
    JIRA_ISSUE_SECURITY_SCHEMES: 'Tag'
    JIRA_ISSUE_TYPES: 'Tag'
    JIRA_ISSUE_TYPE_PROPERTIES: 'Tag'
    JIRA_ISSUE_TYPE_SCHEMES: 'Tag'
    JIRA_ISSUE_TYPE_SCREEN_SCHEMES: 'Tag'
    JIRA_ISSUE_VOTES: 'Tag'
    JIRA_ISSUE_WATCHERS: 'Tag'
    JIRA_ISSUE_WORKLOGS: 'Tag'
    JIRA_ISSUE_WORKLOG_PROPERTIES: 'Tag'
    JIRA_JIRA_EXPRESSIONS: 'Tag'
    JIRA_JIRA_SETTINGS: 'Tag'
    JIRA_JQL: 'Tag'
    JIRA_JQL_FUNCTIONS__APPS_: 'Tag'
    JIRA_LABELS: 'Tag'
    JIRA_LICENSE_METRICS: 'Tag'
    JIRA_MYSELF: 'Tag'
    JIRA_PERMISSIONS: 'Tag'
    JIRA_PERMISSION_SCHEMES: 'Tag'
    JIRA_PROJECTS: 'Tag'
    JIRA_PROJECT_AVATARS: 'Tag'
    JIRA_PROJECT_CATEGORIES: 'Tag'
    JIRA_PROJECT_CLASSIFICATION_LEVELS: 'Tag'
    JIRA_PROJECT_COMPONENTS: 'Tag'
    JIRA_PROJECT_EMAIL: 'Tag'
    JIRA_PROJECT_FEATURES: 'Tag'
    JIRA_PROJECT_KEY_AND_NAME_VALIDATION: 'Tag'
    JIRA_PROJECT_PERMISSION_SCHEMES: 'Tag'
    JIRA_PROJECT_PROPERTIES: 'Tag'
    JIRA_PROJECT_ROLES: 'Tag'
    JIRA_PROJECT_ROLE_ACTORS: 'Tag'
    JIRA_PROJECT_TYPES: 'Tag'
    JIRA_PROJECT_VERSIONS: 'Tag'
    JIRA_SCREENS: 'Tag'
    JIRA_SCREEN_SCHEMES: 'Tag'
    JIRA_SCREEN_TABS: 'Tag'
    JIRA_SCREEN_TAB_FIELDS: 'Tag'
    JIRA_SERVER_INFO: 'Tag'
    JIRA_SERVICE_REGISTRY: 'Tag'
    JIRA_STATUS: 'Tag'
    JIRA_TASKS: 'Tag'
    JIRA_TIME_TRACKING: 'Tag'
    JIRA_UI_MODIFICATIONS__APPS_: 'Tag'
    JIRA_USERS: 'Tag'
    JIRA_USER_PROPERTIES: 'Tag'
    JIRA_USER_SEARCH: 'Tag'
    JIRA_WEBHOOKS: 'Tag'
    JIRA_WORKFLOWS: 'Tag'
    JIRA_WORKFLOW_SCHEMES: 'Tag'
    JIRA_WORKFLOW_SCHEME_DRAFTS: 'Tag'
    JIRA_WORKFLOW_SCHEME_PROJECT_ASSOCIATIONS: 'Tag'
    JIRA_WORKFLOW_STATUSES: 'Tag'
    JIRA_WORKFLOW_STATUS_CATEGORIES: 'Tag'
    JIRA_WORKFLOW_TRANSITION_PROPERTIES: 'Tag'
    JIRA_WORKFLOW_TRANSITION_RULES: 'Tag'
    KLAVIYO_ACCOUNTS: 'Tag'
    KLAVIYO_CAMPAIGNS: 'Tag'
    KLAVIYO_CATALOGS: 'Tag'
    KLAVIYO_CLIENT: 'Tag'
    KLAVIYO_COUPONS: 'Tag'
    KLAVIYO_DATA_PRIVACY: 'Tag'
    KLAVIYO_EVENTS: 'Tag'
    KLAVIYO_FLOWS: 'Tag'
    KLAVIYO_FORMS: 'Tag'
    KLAVIYO_IMAGES: 'Tag'
    KLAVIYO_IMPORTANT: 'Tag'
    KLAVIYO_LISTS: 'Tag'
    KLAVIYO_METRICS: 'Tag'
    KLAVIYO_PROFILES: 'Tag'
    KLAVIYO_REPORTING: 'Tag'
    KLAVIYO_SEGMENTS: 'Tag'
    KLAVIYO_TAGS: 'Tag'
    KLAVIYO_TEMPLATES: 'Tag'
    KLAVIYO_WEBHOOKS: 'Tag'
    LISTENNOTES_DIRECTORY_API: 'Tag'
    LISTENNOTES_IMPORTANT: 'Tag'
    LISTENNOTES_INSIGHTS_API: 'Tag'
    LISTENNOTES_PLAYLIST_API: 'Tag'
    LISTENNOTES_PODCASTER_API: 'Tag'
    LISTENNOTES_SEARCH_API: 'Tag'
    LMNT_ACCOUNT: 'Tag'
    LMNT_SPEECH: 'Tag'
    LMNT_VOICES: 'Tag'
    MAILCHIMP_ACCOUNTEXPORT: 'Tag'
    MAILCHIMP_ACCOUNTEXPORTS: 'Tag'
    MAILCHIMP_ACTIVITYFEED: 'Tag'
    MAILCHIMP_AUTHORIZEDAPPS: 'Tag'
    MAILCHIMP_AUTOMATIONS: 'Tag'
    MAILCHIMP_BATCHES: 'Tag'
    MAILCHIMP_BATCHWEBHOOKS: 'Tag'
    MAILCHIMP_CAMPAIGNFOLDERS: 'Tag'
    MAILCHIMP_CAMPAIGNS: 'Tag'
    MAILCHIMP_CONNECTEDSITES: 'Tag'
    MAILCHIMP_CONVERSATIONS: 'Tag'
    MAILCHIMP_CUSTOMERJOURNEYS: 'Tag'
    MAILCHIMP_ECOMMERCE: 'Tag'
    MAILCHIMP_FACEBOOKADS: 'Tag'
    MAILCHIMP_FILEMANAGER: 'Tag'
    MAILCHIMP_IMPORTANT: 'Tag'
    MAILCHIMP_LANDINGPAGES: 'Tag'
    MAILCHIMP_LISTS: 'Tag'
    MAILCHIMP_PING: 'Tag'
    MAILCHIMP_REPORTING: 'Tag'
    MAILCHIMP_REPORTS: 'Tag'
    MAILCHIMP_ROOT: 'Tag'
    MAILCHIMP_SEARCHCAMPAIGNS: 'Tag'
    MAILCHIMP_SEARCHMEMBERS: 'Tag'
    MAILCHIMP_SURVEYS: 'Tag'
    MAILCHIMP_TEMPLATEFOLDERS: 'Tag'
    MAILCHIMP_TEMPLATES: 'Tag'
    MAILCHIMP_VERIFIEDDOMAINS: 'Tag'
    MEM0_AGENTS: 'Tag'
    MEM0_APPS: 'Tag'
    MEM0_ENTITIES: 'Tag'
    MEM0_EVENTS: 'Tag'
    MEM0_IMPORTANT: 'Tag'
    MEM0_MEMORIES: 'Tag'
    MEM0_ORGANIZATIONS: 'Tag'
    MEM0_PROJECT: 'Tag'
    MEM0_PROJECTS: 'Tag'
    MEM0_RUNS: 'Tag'
    MEM0_STATS: 'Tag'
    MEM0_USERS: 'Tag'
    NOTION_IMPORTANT: 'Tag'
    PIPEDRIVE_ACTIVITIES: 'Tag'
    PIPEDRIVE_ACTIVITYFIELDS: 'Tag'
    PIPEDRIVE_ACTIVITYTYPES: 'Tag'
    PIPEDRIVE_BILLING: 'Tag'
    PIPEDRIVE_CALLLOGS: 'Tag'
    PIPEDRIVE_CHANNELS: 'Tag'
    PIPEDRIVE_CURRENCIES: 'Tag'
    PIPEDRIVE_DEALFIELDS: 'Tag'
    PIPEDRIVE_DEALS: 'Tag'
    PIPEDRIVE_FILES: 'Tag'
    PIPEDRIVE_FILTERS: 'Tag'
    PIPEDRIVE_GOALS: 'Tag'
    PIPEDRIVE_IMPORTANT: 'Tag'
    PIPEDRIVE_ITEMSEARCH: 'Tag'
    PIPEDRIVE_LEADLABELS: 'Tag'
    PIPEDRIVE_LEADS: 'Tag'
    PIPEDRIVE_LEADSOURCES: 'Tag'
    PIPEDRIVE_LEGACYTEAMS: 'Tag'
    PIPEDRIVE_MAILBOX: 'Tag'
    PIPEDRIVE_MEETINGS: 'Tag'
    PIPEDRIVE_NOTEFIELDS: 'Tag'
    PIPEDRIVE_NOTES: 'Tag'
    PIPEDRIVE_OAUTH: 'Tag'
    PIPEDRIVE_ORGANIZATIONFIELDS: 'Tag'
    PIPEDRIVE_ORGANIZATIONRELATIONSHIPS: 'Tag'
    PIPEDRIVE_ORGANIZATIONS: 'Tag'
    PIPEDRIVE_PERMISSIONSETS: 'Tag'
    PIPEDRIVE_PERSONFIELDS: 'Tag'
    PIPEDRIVE_PERSONS: 'Tag'
    PIPEDRIVE_PIPELINES: 'Tag'
    PIPEDRIVE_PRODUCTFIELDS: 'Tag'
    PIPEDRIVE_PRODUCTS: 'Tag'
    PIPEDRIVE_PROJECTS: 'Tag'
    PIPEDRIVE_PROJECTTEMPLATES: 'Tag'
    PIPEDRIVE_RECENTS: 'Tag'
    PIPEDRIVE_ROLES: 'Tag'
    PIPEDRIVE_STAGES: 'Tag'
    PIPEDRIVE_SUBSCRIPTIONS: 'Tag'
    PIPEDRIVE_TASKS: 'Tag'
    PIPEDRIVE_USERCONNECTIONS: 'Tag'
    PIPEDRIVE_USERS: 'Tag'
    PIPEDRIVE_USERSETTINGS: 'Tag'
    PIPEDRIVE_WEBHOOKS: 'Tag'
    POSTHOG_ACTIONS: 'Tag'
    POSTHOG_ACTIVITY_LOG: 'Tag'
    POSTHOG_ANNOTATIONS: 'Tag'
    POSTHOG_APP_METRICS: 'Tag'
    POSTHOG_BATCH_EXPORTS: 'Tag'
    POSTHOG_COHORTS: 'Tag'
    POSTHOG_DASHBOARDS: 'Tag'
    POSTHOG_DASHBOARD_TEMPLATES: 'Tag'
    POSTHOG_DOMAINS: 'Tag'
    POSTHOG_EARLY_ACCESS_FEATURE: 'Tag'
    POSTHOG_EVENTS: 'Tag'
    POSTHOG_EVENT_DEFINITIONS: 'Tag'
    POSTHOG_EXPERIMENTS: 'Tag'
    POSTHOG_EXPLICIT_MEMBERS: 'Tag'
    POSTHOG_EXPORTS: 'Tag'
    POSTHOG_FEATURE_FLAGS: 'Tag'
    POSTHOG_FUNNEL: 'Tag'
    POSTHOG_GROUPS: 'Tag'
    POSTHOG_GROUPS_TYPES: 'Tag'
    POSTHOG_IMPORTANT: 'Tag'
    POSTHOG_INSIGHTS: 'Tag'
    POSTHOG_INVITES: 'Tag'
    POSTHOG_MEMBERS: 'Tag'
    POSTHOG_NOTEBOOKS: 'Tag'
    POSTHOG_ORGANIZATIONS: 'Tag'
    POSTHOG_PERSONS: 'Tag'
    POSTHOG_PIPELINE_DESTINATIONS: 'Tag'
    POSTHOG_PIPELINE_DESTINATION_CONFIGS: 'Tag'
    POSTHOG_PIPELINE_FRONTEND_APPS: 'Tag'
    POSTHOG_PIPELINE_FRONTEND_APPS_CONFIGS: 'Tag'
    POSTHOG_PIPELINE_IMPORT_APPS: 'Tag'
    POSTHOG_PIPELINE_IMPORT_APPS_CONFIGS: 'Tag'
    POSTHOG_PIPELINE_TRANSFORMATIONS: 'Tag'
    POSTHOG_PIPELINE_TRANSFORMATION_CONFIGS: 'Tag'
    POSTHOG_PLUGINS: 'Tag'
    POSTHOG_PLUGIN_CONFIGS: 'Tag'
    POSTHOG_PROJECTS: 'Tag'
    POSTHOG_PROPERTY_DEFINITIONS: 'Tag'
    POSTHOG_PROXY_RECORDS: 'Tag'
    POSTHOG_QUERY: 'Tag'
    POSTHOG_ROLES: 'Tag'
    POSTHOG_SESSIONS: 'Tag'
    POSTHOG_SESSION_RECORDINGS: 'Tag'
    POSTHOG_SESSION_RECORDING_PLAYLISTS: 'Tag'
    POSTHOG_SUBSCRIPTIONS: 'Tag'
    POSTHOG_SURVEYS: 'Tag'
    POSTHOG_TREND: 'Tag'
    POSTHOG_USERS: 'Tag'
    SALESFORCE_ACCOUNT: 'Tag'
    SALESFORCE_CAMPAIGN: 'Tag'
    SALESFORCE_CONTACT: 'Tag'
    SALESFORCE_IMPORTANT: 'Tag'
    SALESFORCE_LEAD: 'Tag'
    SALESFORCE_NOTE: 'Tag'
    SALESFORCE_OPPORTUNITY: 'Tag'
    SENDGRID_ACCOUNT: 'Tag'
    SENDGRID_ACCOUNT_STATE: 'Tag'
    SENDGRID_ALERTS: 'Tag'
    SENDGRID_API_KEYS: 'Tag'
    SENDGRID_BLOCKS: 'Tag'
    SENDGRID_BOUNCES: 'Tag'
    SENDGRID_BULK_EMAIL_ADDRESS_VALIDATION: 'Tag'
    SENDGRID_CAMPAIGNS_API: 'Tag'
    SENDGRID_CATEGORIES: 'Tag'
    SENDGRID_CONTACTS: 'Tag'
    SENDGRID_CUSTOM_FIELDS: 'Tag'
    SENDGRID_DESIGNS: 'Tag'
    SENDGRID_DOMAIN_AUTHENTICATION: 'Tag'
    SENDGRID_EMAIL_ACTIVITY: 'Tag'
    SENDGRID_EMAIL_ADDRESS_VALIDATION: 'Tag'
    SENDGRID_ENFORCED_TLS: 'Tag'
    SENDGRID_ENGAGEMENT_QUALITY: 'Tag'
    SENDGRID_EVENT_WEBHOOK: 'Tag'
    SENDGRID_EXTERNAL_INTEGRATION_ENDPOINTS: 'Tag'
    SENDGRID_GLOBAL_SUPPRESSIONS: 'Tag'
    SENDGRID_IMPORTANT: 'Tag'
    SENDGRID_INVALID_EMAILS: 'Tag'
    SENDGRID_IP_ACCESS_MANAGEMENT: 'Tag'
    SENDGRID_IP_ADDRESSES: 'Tag'
    SENDGRID_IP_ADDRESS_MANAGEMENT: 'Tag'
    SENDGRID_IP_POOLS: 'Tag'
    SENDGRID_IP_WARMUP: 'Tag'
    SENDGRID_LINK_BRANDING: 'Tag'
    SENDGRID_LISTS: 'Tag'
    SENDGRID_MAIL_BATCH: 'Tag'
    SENDGRID_MAIL_SEND: 'Tag'
    SENDGRID_MAIL_SETTINGS: 'Tag'
    SENDGRID_OFFERING: 'Tag'
    SENDGRID_PARSE_WEBHOOK: 'Tag'
    SENDGRID_PARTNER_SETTINGS: 'Tag'
    SENDGRID_POINT_DELETE_SYSTEM: 'Tag'
    SENDGRID_RECIPIENTS: 'Tag'
    SENDGRID_REVERSE_DNS: 'Tag'
    SENDGRID_SCHEDULED_SENDS: 'Tag'
    SENDGRID_SCOPES: 'Tag'
    SENDGRID_SEGMENTING_CONTACTS: 'Tag'
    SENDGRID_SEGMENTING_CONTACTS_V2: 'Tag'
    SENDGRID_SEGMENTS: 'Tag'
    SENDGRID_SENDERS: 'Tag'
    SENDGRID_SENDER_IDENTITIES: 'Tag'
    SENDGRID_SENDER_VERIFICATION: 'Tag'
    SENDGRID_SEND_TEST_EMAIL: 'Tag'
    SENDGRID_SINGLE_SENDS: 'Tag'
    SENDGRID_SPAM_REPORTS: 'Tag'
    SENDGRID_SSO_CERTIFICATES: 'Tag'
    SENDGRID_SSO_SETTINGS: 'Tag'
    SENDGRID_SSO_TEAMMATES: 'Tag'
    SENDGRID_STATS: 'Tag'
    SENDGRID_SUBUSERS: 'Tag'
    SENDGRID_SUBUSER_STATISTICS: 'Tag'
    SENDGRID_SUBUSER_WEBSITE_ACCESS: 'Tag'
    SENDGRID_SUPPRESSIONS: 'Tag'
    SENDGRID_TEAMMATES: 'Tag'
    SENDGRID_TEMPLATES: 'Tag'
    SENDGRID_TEMPLATES_VERSIONS: 'Tag'
    SENDGRID_TRACKING: 'Tag'
    SENDGRID_UNSUBSCRIBE_GROUPS: 'Tag'
    SENDGRID_USERS_API: 'Tag'
    SHOPIFY_IMPORTANT: 'Tag'
    SHOPIFY_PRODUCT_IMAGE: 'Tag'
    SLACKBOT_ADMIN: 'Tag'
    SLACKBOT_ADMIN_APPS: 'Tag'
    SLACKBOT_ADMIN_APPS_APPROVED: 'Tag'
    SLACKBOT_ADMIN_APPS_REQUESTS: 'Tag'
    SLACKBOT_ADMIN_APPS_RESTRICTED: 'Tag'
    SLACKBOT_ADMIN_CONVERSATIONS: 'Tag'
    SLACKBOT_ADMIN_CONVERSATIONS_EKM: 'Tag'
    SLACKBOT_ADMIN_CONVERSATIONS_RESTRICTACCESS: 'Tag'
    SLACKBOT_ADMIN_EMOJI: 'Tag'
    SLACKBOT_ADMIN_INVITEREQUESTS: 'Tag'
    SLACKBOT_ADMIN_INVITEREQUESTS_APPROVED: 'Tag'
    SLACKBOT_ADMIN_INVITEREQUESTS_DENIED: 'Tag'
    SLACKBOT_ADMIN_TEAMS: 'Tag'
    SLACKBOT_ADMIN_TEAMS_ADMINS: 'Tag'
    SLACKBOT_ADMIN_TEAMS_OWNERS: 'Tag'
    SLACKBOT_ADMIN_TEAMS_SETTINGS: 'Tag'
    SLACKBOT_ADMIN_USERGROUPS: 'Tag'
    SLACKBOT_ADMIN_USERS: 'Tag'
    SLACKBOT_ADMIN_USERS_SESSION: 'Tag'
    SLACKBOT_API: 'Tag'
    SLACKBOT_APPS: 'Tag'
    SLACKBOT_APPS_EVENT_AUTHORIZATIONS: 'Tag'
    SLACKBOT_APPS_PERMISSIONS: 'Tag'
    SLACKBOT_APPS_PERMISSIONS_RESOURCES: 'Tag'
    SLACKBOT_APPS_PERMISSIONS_SCOPES: 'Tag'
    SLACKBOT_APPS_PERMISSIONS_USERS: 'Tag'
    SLACKBOT_AUTH: 'Tag'
    SLACKBOT_BOTS: 'Tag'
    SLACKBOT_CALLS: 'Tag'
    SLACKBOT_CALLS_PARTICIPANTS: 'Tag'
    SLACKBOT_CHAT: 'Tag'
    SLACKBOT_CHAT_SCHEDULEDMESSAGES: 'Tag'
    SLACKBOT_CONVERSATIONS: 'Tag'
    SLACKBOT_DIALOG: 'Tag'
    SLACKBOT_DND: 'Tag'
    SLACKBOT_EMOJI: 'Tag'
    SLACKBOT_FILES: 'Tag'
    SLACKBOT_FILES_COMMENTS: 'Tag'
    SLACKBOT_FILES_REMOTE: 'Tag'
    SLACKBOT_IMPORTANT: 'Tag'
    SLACKBOT_MIGRATION: 'Tag'
    SLACKBOT_OAUTH: 'Tag'
    SLACKBOT_OAUTH_V2: 'Tag'
    SLACKBOT_PINS: 'Tag'
    SLACKBOT_REACTIONS: 'Tag'
    SLACKBOT_REMINDERS: 'Tag'
    SLACKBOT_RTM: 'Tag'
    SLACKBOT_SEARCH: 'Tag'
    SLACKBOT_STARS: 'Tag'
    SLACKBOT_TEAM: 'Tag'
    SLACKBOT_TEAM_PROFILE: 'Tag'
    SLACKBOT_USERGROUPS: 'Tag'
    SLACKBOT_USERGROUPS_USERS: 'Tag'
    SLACKBOT_USERS: 'Tag'
    SLACKBOT_USERS_PROFILE: 'Tag'
    SLACKBOT_VIEWS: 'Tag'
    SLACKBOT_WORKFLOWS: 'Tag'
    SLACK_ADMIN: 'Tag'
    SLACK_ADMIN_APPS: 'Tag'
    SLACK_ADMIN_APPS_APPROVED: 'Tag'
    SLACK_ADMIN_APPS_REQUESTS: 'Tag'
    SLACK_ADMIN_APPS_RESTRICTED: 'Tag'
    SLACK_ADMIN_CONVERSATIONS: 'Tag'
    SLACK_ADMIN_CONVERSATIONS_EKM: 'Tag'
    SLACK_ADMIN_CONVERSATIONS_RESTRICTACCESS: 'Tag'
    SLACK_ADMIN_EMOJI: 'Tag'
    SLACK_ADMIN_INVITEREQUESTS: 'Tag'
    SLACK_ADMIN_INVITEREQUESTS_APPROVED: 'Tag'
    SLACK_ADMIN_INVITEREQUESTS_DENIED: 'Tag'
    SLACK_ADMIN_TEAMS: 'Tag'
    SLACK_ADMIN_TEAMS_ADMINS: 'Tag'
    SLACK_ADMIN_TEAMS_OWNERS: 'Tag'
    SLACK_ADMIN_TEAMS_SETTINGS: 'Tag'
    SLACK_ADMIN_USERGROUPS: 'Tag'
    SLACK_ADMIN_USERS: 'Tag'
    SLACK_ADMIN_USERS_SESSION: 'Tag'
    SLACK_API: 'Tag'
    SLACK_APPS: 'Tag'
    SLACK_APPS_EVENT_AUTHORIZATIONS: 'Tag'
    SLACK_APPS_PERMISSIONS: 'Tag'
    SLACK_APPS_PERMISSIONS_RESOURCES: 'Tag'
    SLACK_APPS_PERMISSIONS_SCOPES: 'Tag'
    SLACK_APPS_PERMISSIONS_USERS: 'Tag'
    SLACK_AUTH: 'Tag'
    SLACK_BOTS: 'Tag'
    SLACK_CALLS: 'Tag'
    SLACK_CALLS_PARTICIPANTS: 'Tag'
    SLACK_CHAT: 'Tag'
    SLACK_CHAT_SCHEDULEDMESSAGES: 'Tag'
    SLACK_CONVERSATIONS: 'Tag'
    SLACK_DIALOG: 'Tag'
    SLACK_DND: 'Tag'
    SLACK_EMOJI: 'Tag'
    SLACK_FILES: 'Tag'
    SLACK_FILES_COMMENTS: 'Tag'
    SLACK_FILES_REMOTE: 'Tag'
    SLACK_IMPORTANT: 'Tag'
    SLACK_MIGRATION: 'Tag'
    SLACK_OAUTH: 'Tag'
    SLACK_OAUTH_V2: 'Tag'
    SLACK_PINS: 'Tag'
    SLACK_REACTIONS: 'Tag'
    SLACK_REMINDERS: 'Tag'
    SLACK_RTM: 'Tag'
    SLACK_SEARCH: 'Tag'
    SLACK_STARS: 'Tag'
    SLACK_TEAM: 'Tag'
    SLACK_TEAM_PROFILE: 'Tag'
    SLACK_USERGROUPS: 'Tag'
    SLACK_USERGROUPS_USERS: 'Tag'
    SLACK_USERS: 'Tag'
    SLACK_USERS_PROFILE: 'Tag'
    SLACK_VIEWS: 'Tag'
    SLACK_WORKFLOWS: 'Tag'
    SUPABASE_AUTH: 'Tag'
    SUPABASE_DATABASE: 'Tag'
    SUPABASE_DOMAINS: 'Tag'
    SUPABASE_EDGE_FUNCTIONS: 'Tag'
    SUPABASE_ENVIRONMENTS: 'Tag'
    SUPABASE_IMPORTANT: 'Tag'
    SUPABASE_OAUTH: 'Tag'
    SUPABASE_ORGANIZATIONS: 'Tag'
    SUPABASE_PROJECTS: 'Tag'
    SUPABASE_REST: 'Tag'
    SUPABASE_SECRETS: 'Tag'
    SUPABASE_STORAGE: 'Tag'
    TRELLO_ACTION: 'Tag'
    TRELLO_BATCH: 'Tag'
    TRELLO_BOARD: 'Tag'
    TRELLO_CARD: 'Tag'
    TRELLO_CHECKLIST: 'Tag'
    TRELLO_IMPORTANT: 'Tag'
    TRELLO_LABEL: 'Tag'
    TRELLO_LIST: 'Tag'
    TRELLO_MEMBER: 'Tag'
    TRELLO_NOTIFICATION: 'Tag'
    TRELLO_ORGANIZATION: 'Tag'
    TRELLO_SEARCH: 'Tag'
    TRELLO_SESSION: 'Tag'
    TRELLO_TOKEN: 'Tag'
    TRELLO_TYPE: 'Tag'
    TRELLO_WEBHOOK: 'Tag'
    TWITTER_BOOKMARKS: 'Tag'
    TWITTER_COMPLIANCE: 'Tag'
    TWITTER_DIRECT_MESSAGES: 'Tag'
    TWITTER_GENERAL: 'Tag'
    TWITTER_IMPORTANT: 'Tag'
    TWITTER_LISTS: 'Tag'
    TWITTER_SPACES: 'Tag'
    TWITTER_TWEETS: 'Tag'
    TWITTER_USAGE: 'Tag'
    TWITTER_USERS: 'Tag'
    ZOOM_ARCHIVING: 'Tag'
    ZOOM_CLOUD_RECORDING: 'Tag'
    ZOOM_DEVICES: 'Tag'
    ZOOM_H323_DEVICES: 'Tag'
    ZOOM_IMPORTANT: 'Tag'
    ZOOM_MEETINGS: 'Tag'
    ZOOM_PAC: 'Tag'
    ZOOM_REPORTS: 'Tag'
    ZOOM_SIP_PHONE: 'Tag'
    ZOOM_TRACKING_FIELD: 'Tag'
    ZOOM_TSP: 'Tag'
    ZOOM_WEBINARS: 'Tag'

    @property
    def app(self) -> str:
        """App name for this tag."""
        return self.load().app

    @property
    def value(self) -> str:
        """Tag string."""
        return self.load().value


"""
Local storage helpers.
"""

import json
import typing as t
from pathlib import Path

import typing_extensions as tx
from pydantic import BaseModel


class LocalStorage(BaseModel):
    """
    Local storage object.

    Example:
    ```python
        from pathlib import Path

        class User(LocalStorage):
            '''User account object'''

            name: str

        user = User(name="John", path=Path("user.json"))
        print (user.name)
        user.store()

        user = User.load(Path("user.json"))
        print (user.name)
    ```

    Note:
        When deriving from the `LocalStorage` class, `path` needs to be
        defined as a class variable.
    """

    path: t.Optional[Path] = None

    def to_json(self) -> t.Dict:
        """Convert object to JSON dictionary."""
        return self.model_dump()

    @classmethod
    def from_json(cls, obj: t.Dict, path: t.Optional[Path] = None) -> tx.Self:
        """Load from json object."""
        return cls(**obj, path=path)

    def store(self) -> None:
        """Store object as a JSON file."""
        if self.path is None:
            raise ValueError(
                f"Value of `path` is not set for `{self.__class__.__name__}`"
            )

        data = self.to_json()
        if "path" in data:
            del data["path"]

        self.path.write_text(
            json.dumps(
                data,
                indent=2,
            ),
            encoding="utf-8",
        )

    @classmethod
    def load(cls, path: Path) -> tx.Self:
        """Load user account from cache."""
        return cls.from_json(
            obj=json.loads(
                path.read_text(
                    encoding="utf-8",
                )
            ),
            path=path,
        )



import typing as t

from composio.client.enums import Action, ActionType, App, AppType, Tag, TagType
from composio.tools.base.abs import Action as LocalActionType
from composio.tools.base.abs import Tool as LocalToolType
from composio.tools.base.abs import action_registry
from composio.utils.logging import WithLogger


_runtime_actions: t.Dict[str, LocalActionType] = {}


class LocalClient(WithLogger):
    """Local tools client."""

    _tools: t.Dict[str, LocalToolType] = {}
    """Local tools registry."""

    @classmethod
    def tools(cls) -> t.Dict[str, LocalToolType]:
        """Local tools."""
        from composio.tools.local import (  # pylint: disable=import-outside-toplevel
            load_local_tools,
        )

        cls._tools = load_local_tools().get("local", {})
        return cls._tools

    @classmethod
    def get_action_schemas(
        cls,
        apps: t.Optional[t.Sequence[AppType]] = None,
        actions: t.Optional[t.Sequence[ActionType]] = None,
        tags: t.Optional[t.Sequence[TagType]] = None,
    ) -> t.List[t.Dict]:
        """Get action schemas for given parameters."""
        tools = cls.tools()
        apps = t.cast(t.List[App], [App(app) for app in apps or []])
        actions = t.cast(t.List[Action], [Action(action) for action in actions or []])
        action_schemas: t.List[t.Dict] = []

        for app in apps:
            action_schemas += [action.schema() for action in tools[app.slug].actions()]

        for action in actions:
            action_schemas.append(action_registry["local"][action.slug].schema())

        if tags:
            tags = t.cast(t.List[str], [Tag(tag).value for tag in tags or []])
            action_schemas = [
                action_schema
                for action_schema in action_schemas
                if bool(set(tags) & set(action_schema["tags"]))
            ]

        for schema in action_schemas:
            schema["name"] = schema["enum"]

        return action_schemas


def add_runtime_action(name: str, cls: t.Type[LocalActionType]) -> None:
    """Add runtime action."""
    _runtime_actions[name] = cls()


def get_runtime_action(name: str) -> LocalActionType:
    """Get a runtime action."""
    return _runtime_actions[name]



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class GetFilteredTeamTasksRequest(BaseModel):
    """Request schema for `GetFilteredTeamTasks`"""

    team_Id: int = Field(
        ...,
        alias="team_Id",
        description="Team ID (Workspace)",
    )
    page: int = Field(
        default=None,
        alias="page",
        description="Page to fetch (starts at 0).",
    )
    order_by: str = Field(
        default=None,
        alias="order_by",
        description=(
            "Order by a particular field. By default, tasks are ordered by `created`. "
            "  Options include: `id`, `created`, `updated`, and `due_date`. "
        ),
    )
    reverse: bool = Field(
        default=None,
        alias="reverse",
        description="Tasks are displayed in reverse order.",
    )
    subtasks: bool = Field(
        default=None,
        alias="subtasks",
        description="Include or exclude subtasks. By default, subtasks are excluded.",
    )
    space_ids: t.List[str] = Field(
        default=None,
        alias="space_ids",
        description="Filter by Spaces. For example:    `?space_ids[]=1234&space_ids[]=6789`",
    )
    project_ids: t.List[str] = Field(
        default=None,
        alias="project_ids",
        description=(
            "Filter by Folders. For example:    `?project_ids[]=1234&project_ids[]=6789` "
        ),
    )
    list_ids: t.List[str] = Field(
        default=None,
        alias="list_ids",
        description="Filter by Lists. For example:    `?list_ids[]=1234&list_ids[]=6789`",
    )
    statuses: t.List[str] = Field(
        default=None,
        alias="statuses",
        description=(
            "Filter by statuses. Use `%20` to represent a space character. To include "
            "closed tasks, use the `include_closed` parameter.    For example:    `?statuses[]=to%20do&statuses[]=in%20progress` "
        ),
    )
    include_closed: bool = Field(
        default=None,
        alias="include_closed",
        description=(
            "Include or exclude closed tasks. By default, they are excluded.   To include "
            "closed tasks, use `include_closed: true`. "
        ),
    )
    assignees: t.List[str] = Field(
        default=None,
        alias="assignees",
        description=(
            'Filter by Assignees using people"s ClickUp user id. For example:    `?assignees[]=1234&assignees[]=5678` '
        ),
    )
    tags: t.List[str] = Field(
        default=None,
        alias="tags",
        description=(
            "Filter by tags. User `%20` to represent a space character. For example: "
            "   `?tags[]=tag1&tags[]=this%20tag` "
        ),
    )
    due_date_gt: int = Field(
        default=None,
        alias="due_date_gt",
        description="Filter by due date greater than Unix time in milliseconds.",
    )
    due_date_lt: int = Field(
        default=None,
        alias="due_date_lt",
        description="Filter by due date less than Unix time in milliseconds.",
    )
    date_created_gt: int = Field(
        default=None,
        alias="date_created_gt",
        description="Filter by date created greater than Unix time in milliseconds.",
    )
    date_created_lt: int = Field(
        default=None,
        alias="date_created_lt",
        description="Filter by date created less than Unix time in milliseconds.",
    )
    date_updated_gt: int = Field(
        default=None,
        alias="date_updated_gt",
        description="Filter by date updated greater than Unix time in milliseconds.",
    )
    date_updated_lt: int = Field(
        default=None,
        alias="date_updated_lt",
        description="Filter by date updated less than Unix time in milliseconds.",
    )
    date_done_gt: int = Field(
        default=None,
        alias="date_done_gt",
        description="Filter by date done greater than Unix time in milliseconds.",
    )
    date_done_lt: int = Field(
        default=None,
        alias="date_done_lt",
        description="Filter by date done less than Unix time in milliseconds.",
    )
    custom_fields: t.List[str] = Field(
        default=None,
        alias="custom_fields",
        description=(
            "Include tasks with specific values in one or more Custom Fields.   For example: "
            '`?custom_fields=[{"field_id":"abcdefghi12345678","operator":"=","value":"1234"}{"field_id":"jklmnop123456","operator":"<","value":"5"}]` '
            "  Learn more about [filtering using Custom Fields.](https://clickup.com/api) "
        ),
    )
    custom_task_ids: bool = Field(
        default=None,
        alias="custom_task_ids",
        description=(
            'If you want to reference a task by it"s custom task id, this value must '
            "be `true`. "
        ),
    )
    team_id: int = Field(
        default=None,
        alias="team_id",
        description=(
            "Only used when the `custom_task_ids` parameter is set to `true`.   For example: "
            "`custom_task_ids=true&team_id=123`. "
        ),
    )
    parent: str = Field(
        default=None,
        alias="parent",
        description="Include the parent task ID to return subtasks.",
    )
    include_markdown_description: bool = Field(
        default=None,
        alias="include_markdown_description",
        description=(
            "To return task descriptions in Markdown format, use `?include_markdown_description=true`. "
        ),
    )
    custom_items: t.List[int] = Field(
        default=None,
        alias="custom_items",
        description=(
            "Filter by custom task types. For example:    `?custom_items[]=0&custom_items[]=1300` "
            "   Including `0` returns tasks. Including `1` returns Milestones. Including "
            "any other number returns the custom task type as defined in your Workspace. "
        ),
    )


class GetFilteredTeamTasksResponse(BaseModel):
    """Response schema for `GetFilteredTeamTasks`"""

    data: t.Dict[str, t.Any]


class GetFilteredTeamTasks(OpenAPIAction):
    """
    View the tasks that meet specific criteria from a Workspace. Responses are
    limited to 100 tasks per page.     You can only view task information of
    tasks you can access.
    """

    _tags = ["Tasks"]
    _display_name = "get_filtered_team_tasks"
    _request_schema = GetFilteredTeamTasksRequest
    _response_schema = GetFilteredTeamTasksResponse

    url = "https://api.clickup.com/api/v2"
    path = "/team/{team_Id}/task"
    method = "get"
    operation_id = "Tasks_filterTeamTasks"
    action_identifier = "/team/{team_Id}/task_get"

    path_params = {"team_Id": "team_Id"}
    query_params = {
        "page": "page",
        "order_by": "order_by",
        "reverse": "reverse",
        "subtasks": "subtasks",
        "space_ids": "space_ids",
        "project_ids": "project_ids",
        "list_ids": "list_ids",
        "statuses": "statuses",
        "include_closed": "include_closed",
        "assignees": "assignees",
        "tags": "tags",
        "due_date_gt": "due_date_gt",
        "due_date_lt": "due_date_lt",
        "date_created_gt": "date_created_gt",
        "date_created_lt": "date_created_lt",
        "date_updated_gt": "date_updated_gt",
        "date_updated_lt": "date_updated_lt",
        "date_done_gt": "date_done_gt",
        "date_done_lt": "date_done_lt",
        "custom_fields": "custom_fields",
        "custom_task_ids": "custom_task_ids",
        "team_id": "team_id",
        "parent": "parent",
        "include_markdown_description": "include_markdown_description",
        "custom_items": "custom_items",
    }
    header_params = {}
    request_params = {}

    aliases = {}



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class CreateTaskRequest(BaseModel):
    """Request schema for `CreateTask`"""

    list_id: int = Field(
        ...,
        alias="list_id",
        description="",
    )
    custom_task_ids: bool = Field(
        default=None,
        alias="custom_task_ids",
        description=(
            'If you want to reference a task by it"s custom task id, this value must '
            "be `true`. "
        ),
    )
    team_id: int = Field(
        default=None,
        alias="team_id",
        description=(
            "Only used when the `custom_task_ids` parameter is set to `true`.   For example: "
            "`custom_task_ids=true&team_id=123`. "
        ),
    )
    tags: t.List[str] = Field(
        default=None,
        alias="tags",
        description="",
    )
    description: str = Field(
        default=None,
        alias="description",
        description="Description",
    )
    name: str = Field(
        default=...,
        alias="name",
        description="Name",
    )
    assignees: t.List[int] = Field(
        default=None,
        alias="assignees",
        description="",
    )
    status: str = Field(
        default=None,
        alias="status",
        description="Status",
    )
    priority: int = Field(
        default=None,
        alias="priority",
        description="Priority",
    )
    due_date: int = Field(
        default=None,
        alias="due_date",
        description="Due Date",
    )
    due_date_time: bool = Field(
        default=None,
        alias="due_date_time",
        description="Due Date Time",
    )
    time_estimate: int = Field(
        default=None,
        alias="time_estimate",
        description="Time Estimate",
    )
    start_date: int = Field(
        default=None,
        alias="start_date",
        description="Start Date",
    )
    start_date_time: bool = Field(
        default=None,
        alias="start_date_time",
        description="Start Date Time",
    )
    notify_all: bool = Field(
        default=None,
        alias="notify_all",
        description=(
            "If `notify_all` is true, notifications will be sent to everyone including "
            "the creator of the comment. "
        ),
    )
    parent: str = Field(
        default=None,
        alias="parent",
        description=(
            "You can create a subtask by including an existing task ID.   The `parent` "
            "task ID you include cannot be a subtask, and must be in the same List specified "
            "in the path parameter. "
        ),
    )
    links_to: str = Field(
        default=None,
        alias="links_to",
        description="Include a task ID to create a linked dependency with your new task.",
    )
    check_required_custom_fields: bool = Field(
        default=None,
        alias="check_required_custom_fields",
        description=(
            "When creating a task via API any required Custom Fields are ignored by default "
            "(`false`).   You can enforce required Custom Fields by including `check_required_custom_fields: "
            "true`. "
        ),
    )
    custom_fields: t.List[dict] = Field(
        default=None,
        alias="custom_fields",
        description="[Filter by Custom Fields.](https://clickup.com/api)",
    )
    custom_item_id: int = Field(
        default=None,
        alias="custom_item_id",
        description=(
            'To create a task that doesn"t use a custom task type, either don"t include '
            'this field in the request body, or send `"null"`.    To create this task '
            "as a Milestone, send a value of `1`.   To use a custom task type, send the "
            "custom task type ID as defined in your Workspace, such as `2`. "
        ),
    )


class CreateTaskResponse(BaseModel):
    """Response schema for `CreateTask`"""

    data: t.Dict[str, t.Any]


class CreateTask(OpenAPIAction):
    """Create a new task."""

    _tags = ["Tasks"]
    _display_name = "create_task"
    _request_schema = CreateTaskRequest
    _response_schema = CreateTaskResponse

    url = "https://api.clickup.com/api/v2"
    path = "/list/{list_id}/task"
    method = "post"
    operation_id = "Tasks_createNewTask"
    action_identifier = "/list/{list_id}/task_post"

    path_params = {"list_id": "list_id"}
    query_params = {"custom_task_ids": "custom_task_ids", "team_id": "team_id"}
    header_params = {}
    request_params = {
        "tags": {"__alias": "tags"},
        "description": {"__alias": "description"},
        "name": {"__alias": "name"},
        "assignees": {"__alias": "assignees"},
        "status": {"__alias": "status"},
        "priority": {"__alias": "priority"},
        "due_date": {"__alias": "due_date"},
        "due_date_time": {"__alias": "due_date_time"},
        "time_estimate": {"__alias": "time_estimate"},
        "start_date": {"__alias": "start_date"},
        "start_date_time": {"__alias": "start_date_time"},
        "notify_all": {"__alias": "notify_all"},
        "parent": {"__alias": "parent"},
        "links_to": {"__alias": "links_to"},
        "check_required_custom_fields": {"__alias": "check_required_custom_fields"},
        "custom_fields": {"__alias": "custom_fields"},
        "custom_item_id": {"__alias": "custom_item_id"},
    }

    aliases = {}



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class StartATimeEntryRequest(BaseModel):
    """Request schema for `StartATimeEntry`"""

    team_Id: int = Field(
        ...,
        alias="team_Id",
        description="Team ID (Workspace)",
    )
    custom_task_ids: bool = Field(
        default=None,
        alias="custom_task_ids",
        description=(
            'If you want to reference a task by it"s custom task id, this value must '
            "be `true`. "
        ),
    )
    team_id: int = Field(
        default=None,
        alias="team_id",
        description=(
            "Only used when the `custom_task_ids` parameter is set to `true`.   For example: "
            "`custom_task_ids=true&team_id=123`. "
        ),
    )
    tags: t.List[dict] = Field(
        default=None,
        alias="tags",
        description="Users on the Business Plan and above can include a time tracking label.",
    )
    description: str = Field(
        default=None,
        alias="description",
        description="Description",
    )
    tid: str = Field(
        default=None,
        alias="tid",
        description="Tid",
    )
    billable: bool = Field(
        default=None,
        alias="billable",
        description="Billable",
    )


class StartATimeEntryResponse(BaseModel):
    """Response schema for `StartATimeEntry`"""

    data: t.Dict[str, t.Any]


class StartATimeEntry(OpenAPIAction):
    """Start a timer for the authenticated user."""

    _tags = ["Time Tracking"]
    _display_name = "start_a_time_entry"
    _request_schema = StartATimeEntryRequest
    _response_schema = StartATimeEntryResponse

    url = "https://api.clickup.com/api/v2"
    path = "/team/{team_Id}/time_entries/start"
    method = "post"
    operation_id = "TimeTracking_startTimer"
    action_identifier = "/team/{team_Id}/time_entries/start_post"

    path_params = {"team_Id": "team_Id"}
    query_params = {"custom_task_ids": "custom_task_ids", "team_id": "team_id"}
    header_params = {}
    request_params = {
        "tags": {"__alias": "tags"},
        "description": {"__alias": "description"},
        "tid": {"__alias": "tid"},
        "billable": {"__alias": "billable"},
    }

    aliases = {}



"""Tool for creating a new shell session."""

from pydantic import BaseModel, Field

from composio.tools.base.local import LocalAction


class ShellCreateRequest(BaseModel):
    """Execute command request."""


class ShellCreateResponse(BaseModel):
    """Shell execution response."""

    shell_id: str = Field(
        ...,
        description="Output captured from the execution of the command",
    )


class CreateShell(LocalAction[ShellCreateRequest, ShellCreateResponse]):
    """Use this tool to create a new shell session."""

    _tags = ["workspace", "shell", "create"]

    def execute(
        self,
        request: ShellCreateRequest,
        metadata: dict,
    ) -> ShellCreateResponse:
        """Execute a shell command."""
        return ShellCreateResponse(shell_id=self.shells.new().id)



"""
Action for navigating browser history.
"""

from typing import Optional

from pydantic import Field

from composio.tools.env.browsermanager.manager import BrowserManager
from composio.tools.local.browsertool.actions.base_action import (
    BaseBrowserAction,
    BaseBrowserRequest,
    BaseBrowserResponse,
)


class NavigateHistoryRequest(BaseBrowserRequest):
    """Request schema for navigating browser history."""

    direction: str = Field(
        ..., description="Direction to navigate: 'back' or 'forward'"
    )
    steps: int = Field(
        default=1,
        ge=1,
        description="Number of steps to navigate in the specified direction",
    )


class NavigateHistoryResponse(BaseBrowserResponse):
    """Response schema for navigating browser history."""

    success: bool = Field(
        default=False, description="Whether the navigation action was successful"
    )
    previous_url: Optional[str] = Field(
        default=None, description="URL before navigation"
    )
    message: Optional[str] = Field(
        default=None, description="Additional information about the navigation result"
    )


class NavigateHistory(
    BaseBrowserAction[NavigateHistoryRequest, NavigateHistoryRequest]
):
    """
    Navigate browser history.

    This action allows for navigation through the browser's history, either
    backward or forward, for a specified number of steps.
    """

    display_name = "Navigate History"

    _request_schema = NavigateHistoryRequest
    _response_schema = NavigateHistoryResponse

    def execute_on_browser_manager(
        self, browser_manager: BrowserManager, request: NavigateHistoryRequest  # type: ignore
    ) -> NavigateHistoryResponse:
        """Execute the navigate history action."""
        previous_url = browser_manager.get_current_url()
        navigation_method = browser_manager.back
        if request.direction == "forward":
            navigation_method = browser_manager.forward
        steps_taken = 0
        message = None

        for _ in range(request.steps):
            try:
                navigation_method()
                steps_taken += 1
            except Exception:
                # Reached the limit of history
                method_direction = "backs"
                if request.direction == "forward":
                    method_direction = "forwards"
                message = f"Maximum {method_direction} reached after {steps_taken} steps. Can't go any further."
                break

        return NavigateHistoryResponse(
            success=True, previous_url=previous_url, message=message
        )



from pydantic import Field

from composio.tools.base.local import LocalAction

from .base_workspace_action import BaseWorkspaceRequest, BaseWorkspaceResponse


class WorkspaceStatusRequest(BaseWorkspaceRequest):
    workspace_id: str = Field(
        ...,
        description="workspace-id will be used to get status of the workspace",
    )


class WorkspaceStatusResponse(BaseWorkspaceResponse):
    workspace_status: str = Field(
        ..., description="status of the workspace given in request"
    )


class WorkspaceStatusAction(
    LocalAction[
        WorkspaceStatusRequest,
        WorkspaceStatusResponse,
    ]
):
    """
    Returns the status of workspace given in the request
    """

    def execute(
        self, request: WorkspaceStatusRequest, metadata: dict
    ) -> WorkspaceStatusResponse:
        # TODO: Implement shell status
        return WorkspaceStatusResponse(workspace_status="runinng")



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class GetFolderRequest(BaseModel):
    """Request schema for `GetFolder`"""

    folder_id: int = Field(
        ...,
        alias="folder_id",
        description="",
    )


class GetFolderResponse(BaseModel):
    """Response schema for `GetFolder`"""

    data: t.Dict[str, t.Any]


class GetFolder(OpenAPIAction):
    """View the Lists within a Folder."""

    _tags = ["Folders"]
    _display_name = "get_folder"
    _request_schema = GetFolderRequest
    _response_schema = GetFolderResponse

    url = "https://api.clickup.com/api/v2"
    path = "/folder/{folder_id}"
    method = "get"
    operation_id = "Folders_getFolderContent"
    action_identifier = "/folder/{folder_id}_get"

    path_params = {"folder_id": "folder_id"}
    query_params = {}
    header_params = {}
    request_params = {}

    aliases = {}


class folders_get_folder_content(OpenAPIAction):
    """View the Lists within a Folder.<<DEPRECATED use get_folder>>"""

    _tags = ["Folders"]
    _display_name = "folders_get_folder_content"
    _request_schema = GetFolderRequest
    _response_schema = GetFolderResponse

    url = "https://api.clickup.com/api/v2"
    path = "/folder/{folder_id}"
    method = "get"
    operation_id = "Folders_getFolderContent"
    action_identifier = "/folder/{folder_id}_get"

    path_params = {"folder_id": "folder_id"}
    query_params = {}
    header_params = {}
    request_params = {}

    aliases = {}



import os


SCRIPT_CURSOR_DEFAULT = "/root/commands/defaults.sh"
SCRIPT_EDIT_LINTING = "/root/commands/edit_linting.sh"
SCRIPT_SEARCH = "/root/commands/search.sh"


def git_reset_cmd(commit_id) -> str:
    """Commands to reset git repository state."""
    reset_commands = [
        "git remote get-url origin",
        "git fetch --all",
        f"git reset --hard {commit_id}",
        "git clean -fdx",
    ]
    return " && ".join(reset_commands)


def git_clone_cmd(request_data):
    """Commands to clone github repository."""
    *_, reponame = request_data.repo_name.lstrip().rstrip().split("/")
    github_access_token = os.environ.get("GITHUB_ACCESS_TOKEN")
    if not github_access_token or not github_access_token.strip():
        if os.environ.get("ALLOW_CLONE_WITHOUT_REPO") != "true":
            raise RuntimeError(
                "Cannot clone github repository without github access token"
            )
        commands = [
            f"git clone --progress https://github.com/{request_data.repo_name}.git",
            f"cd {reponame}",
        ]
    else:
        commands = [
            f"git clone --progress https://{github_access_token}@github.com/{request_data.repo_name}.git",
            f"cd {reponame}",
        ]
    if request_data.commit_id:
        commands.append(f"git reset --hard {request_data.commit_id}")
    return " && ".join(commands)


def git_tree_cmd() -> str:
    """Command for creating git tree."""
    return "git ls-tree -r HEAD --name-only > ./git_repo_tree.txt"



"""Virtual file pointer implementation."""

import re
import subprocess
import sys
import typing as t
from collections import deque
from enum import Enum
from pathlib import Path

import typing_extensions as te

from composio.utils.logging import WithLogger


SCROLL_UP = "up"
SCROLL_DOWN = "down"

SCOPE_FILE = "file"
SCOPE_WINDOW = "window"


class ScrollDirection(str, Enum):
    UP = "up"
    DOWN = "down"

    def offset(self, lines: int) -> int:
        """Multiply the window by scroll direction."""
        return lines * (-1 if self.value == "up" else 1)


class FileOperationScope(str, Enum):
    FILE = "file"
    WINDOW = "window"


class Match(te.TypedDict):
    """Match object."""

    content: str
    match: str
    end: int
    start: int
    lineno: int


class TextReplacement(te.TypedDict):
    """Text replacement response."""

    replaced_with: str
    replaced_text: str
    error: te.NotRequired[str]


class File(WithLogger):
    """File object for file manager."""

    _start: int
    _end: int
    _history: deque  # TOFIX: Possible memory leak

    def __init__(
        self,
        path: Path,
        workdir: Path,
        window: t.Optional[int] = None,
    ) -> None:
        """
        Initialize file object

        :param path: Path to file.
        :param workdir: Current working directory.
        :param window: Size of the view window, default is 100.
        """
        super().__init__()
        self.path = path
        self.workdir = workdir

        # View window
        self._start = 0
        self._end = window or 100
        self._window = window or 100
        self._history = deque(maxlen=10)  # Store last 10 versions

    def scroll(
        self,
        lines: t.Optional[int] = None,
        to_line: t.Optional[int] = None,
        direction: t.Optional[ScrollDirection] = None,
    ) -> None:
        """
        Scroll to given number of lines.

        :param lines: Number of lines to scroll.
        :param to_line: Line number to scroll to.
        :param direction: Direction of scrolling.
        :return: None
        """
        direction = direction or ScrollDirection.DOWN
        if to_line:
            half_window = self._window // 2
            if to_line < half_window:
                self._start = 0
                self._end = self._window
            if to_line > self.total_lines() - half_window:
                self._start = self.total_lines() - self._window
                self._end = self.total_lines()
            else:
                self._start = to_line - half_window
                self._end = to_line + half_window
        else:
            lines = direction.offset(lines or self._window)
            self._start += lines
            self._end += lines

    def goto(
        self,
        line: int,
    ) -> None:
        """
        Go to given line number.

        :param line: Line number to go to.
        :return: None
        """
        total_lines = self.total_lines()
        if line >= total_lines:
            raise Exception(
                f"Line number {line} is out of bounds for file with {total_lines} lines"
            )
        self._start = line
        self._end = line + self._window

    def _find(self, buffer: str, pattern: str, lineno: int) -> t.List[Match]:
        """Find the occurrences for given pattern in the buffer."""
        matches: t.List[Match] = []
        for match in re.finditer(pattern=pattern, string=buffer):
            start = match.start()
            end = match.end()
            matches.append(
                {
                    "content": match.string,
                    "match": match.string[start:end],
                    "end": end,
                    "start": start,
                    "lineno": lineno,
                }
            )
        return matches

    def _find_window(self, pattern: str) -> t.List[Match]:
        """Find in the current window."""
        offset = self._start
        matches = []
        for lineno, line in enumerate(self._iter_window()):
            matches += self._find(
                buffer=line,
                pattern=pattern,
                lineno=lineno + offset,
            )
        return matches

    def _find_file(
        self,
        pattern: str,
    ) -> t.List[Match]:
        """Find in the whole file."""
        matches = []
        for lineno, line in enumerate(self._iter_file()):
            matches += self._find(
                buffer=line,
                pattern=pattern,
                lineno=lineno,
            )
        return matches

    def find(
        self,
        pattern: str,
        scope: t.Optional[FileOperationScope] = None,
    ) -> t.List[Match]:
        """
        Find pattern in the given file.

        :param pattern: Pattern to search for
        :param scope: Scope for the search, choose between `file` and `window`.
            if you choose `file`, the search will be performed across the file else
            the search will be performed over the current view window.
        :return: List of matches found for the given pattern
        """
        scope = scope or FileOperationScope.FILE
        if scope == FileOperationScope.FILE:
            return self._find_file(pattern=pattern)
        return self._find_window(pattern=pattern)

    def _iter_window(self) -> t.Iterable[str]:
        """Iter data from the current window."""
        cursor = 0
        with self.path.open("r") as fp:
            while cursor < self._start:
                _ = fp.readline()
                cursor += 1
            while cursor < self._end:
                line = fp.readline()
                if not line:
                    break
                yield line
                cursor += 1

    def _iter_file(self) -> t.Iterable[str]:
        """Iter data from the current file."""
        with self.path.open(mode="r") as fp:
            while True:
                line = fp.readline()
                if not line:
                    break
                yield line

    def iter(self, scope: t.Optional[FileOperationScope] = None) -> t.Iterable[str]:
        """Iter data from the current window or file."""
        scope = scope or FileOperationScope.FILE
        if scope == FileOperationScope.WINDOW:
            return self._iter_window()
        return self._iter_file()

    def read(self) -> t.Dict[int, str]:
        """Read data from file."""
        cursor = 0
        buffer = {}
        with self.path.open("r") as fp:
            while cursor < self._start:
                _ = fp.readline()
                cursor += 1
            while cursor < self._end:
                line = fp.readline()
                if not line:
                    break
                buffer[cursor + 1] = line
                cursor += 1
        return buffer

    def write(self, text: str) -> None:
        """Write the given content to the file."""
        self._history.append(self.path.read_text(encoding="utf-8"))
        self.path.write_text(text, encoding="utf-8")

    def total_lines(self) -> int:
        """Total number of lines in the file."""
        return sum(1 for _ in self._iter_file())

    def format_text(self, lines: t.Dict[int, str]) -> str:
        """Format the text to be written to the file."""
        total_lines = self.total_lines()
        code = ""
        if len(lines) == 0:
            return code
        code += f"[File: {self.path}] ({total_lines} lines total)]\n"
        code += f"({list(lines.keys())[0] - 1} line above)\n"
        max_line_num_width = len(str(max(lines.keys())))
        code += "\n".join(
            f"{line_num:<{max_line_num_width}}:{line_content.rstrip()}"
            for line_num, line_content in lines.items()
        )
        code += f"\n({total_lines - list(lines.keys())[-1]} line below)\n"
        return code

    def edit(
        self,
        text: str,
        start: int,
        end: int,
        scope: t.Optional[FileOperationScope] = None,
    ) -> TextReplacement:
        """
        Write given content to file

        :param text: Content to write to file.
        :param scope: Scope of the file operation
        :param start: Line number to start the edit at
        :param end: Line number before which to end the edit
        :return: Replaced text
        """
        text = text + "\n"
        scope = scope or FileOperationScope.FILE
        end = end - 1
        # Store original content
        original_content = self.path.read_text(encoding="utf-8")

        # Run lint before edit
        before_lint = self.lint()

        cursor = 0
        buffer = ""
        replaced = ""
        with self.path.open(mode="r") as fp:
            if scope == FileOperationScope.WINDOW:
                while cursor < self._start:
                    _ = fp.readline()
                    cursor += 1
                cursor = 0

            # Read lines before the edit
            while cursor < (start - 1):
                buffer += fp.readline()
                cursor += 1

            # Read lines to be replaced
            if end > 0:
                while cursor <= end:
                    replaced += fp.readline()
                    cursor += 1

            # Add the new text
            buffer += text

            # Read the rest of the file
            buffer += fp.read()

        self.path.write_text(data=buffer, encoding="utf-8")

        # Run lint after edit
        after_lint = self.lint()

        self.logger.debug(f"Before lint: {before_lint}")
        self.logger.debug(f"After lint: {after_lint}")
        # Compare lint results
        new_lint_errors = self._compare_lint_results(
            before=before_lint, after=after_lint
        )

        if len(new_lint_errors) > 0:
            # Revert changes if new lint errors are found
            formatted_errors = self._format_lint_errors(errors=new_lint_errors)
            formatted_output = formatted_errors + self._show_file_modifications(
                start=start,
                end=end,
                original_content=original_content,
                buffer=buffer,
                text=text,
            )
            return {
                "replaced_text": "",
                "replaced_with": "",
                "error": f"Edit reverted due to new lint errors:\n{formatted_output}",
            }

        start_original = max(0, start - 5)
        end_original = min(len(original_content.splitlines()), end + 5)

        start_new = max(0, start - 5)
        end_new = min(self.total_lines(), start + len(text.splitlines()) + 5)

        return {
            "replaced_text": self.format_text(
                {
                    x + 1: original_content.splitlines()[x]
                    for x in range(start_original, end_original)
                }
            ),
            "replaced_with": self.format_text(
                {x + 1: buffer.splitlines()[x] for x in range(start_new, end_new)}
            ),
            "error": "",
        }

    def lint(self) -> t.List[str]:
        """Run lint on the file."""
        if self.path.suffix == ".py":
            venv_python = sys.executable
            try:
                result = subprocess.run(
                    [
                        venv_python,
                        "-m",
                        "flake8",
                        "--isolated",
                        "--select=E9,F821,F823,F831,F406,F407,F701,F702,F704,F706,E999,E902,E111,E112,E113",
                        str(self.path),
                    ],
                    capture_output=True,
                    text=True,
                    check=True,
                )
                lint_output = result.stdout
            except subprocess.CalledProcessError as e:
                # If flake8 returns a non-zero exit code, it will raise this exception
                lint_output = e.stdout  # Use stdout for linting errors
                if e.stderr:  # Check if there's any stderr output
                    lint_output += f"\nError running flake8: {e.stderr}"

            return [line.strip() for line in lint_output.split("\n") if line.strip()]
        return []

    def _compare_lint_results(
        self, before: t.List[str], after: t.List[str]
    ) -> t.List[str]:
        """Compare lint results before and after edit."""

        def parse_lint_error(error: str) -> t.Tuple[str, str, str, str, str]:
            """Parse a lint error into (file_name, line_number, error_code, error_message)."""
            parts = error.split(":", 3)
            if len(parts) >= 4:
                file_name = parts[0]
                line_number = parts[1]
                column_number = parts[2]
                error_code = parts[3].split()[0]
                error_message = ":".join(parts[3:]).strip()
                return file_name, line_number, column_number, error_code, error_message
            return "", "", "", "", error

        before_errors = set(
            (error_code, error_message)
            for _, _, _, error_code, error_message in map(parse_lint_error, before)
        )
        after_errors = set(
            (error_code, error_message)
            for _, _, _, error_code, error_message in map(parse_lint_error, after)
        )

        new_errors = after_errors - before_errors
        return [
            f"{file_name}:{line_number}:{column_number} - {code}: {message}"
            for file_name, line_number, column_number, code, message in map(
                parse_lint_error, after
            )
            if (code, message) in new_errors
        ]

    def _format_lint_errors(
        self,
        errors: t.List[str],
    ) -> str:
        """Format a single lint error."""
        formatted_output = ""
        file_lines = self.path.read_text(encoding="utf-8").splitlines()
        for error in errors:
            parts = error.split(":", 3)
            if len(parts) >= 4:
                file_path, line, column, message = parts
                line_content = file_lines[int(line.strip()) - 1]
                formatted_output += f"- File: {file_path.strip()}, Line {line.strip()}, Column {column.strip()}: {message.strip()}\n"
                formatted_output += f"  Error code line: {line_content.strip()}\n"

                # Add description and next action based on error code
                error_code = message.split()[0]
                description, next_action = self._get_error_info(error_code)
                formatted_output += f"  Description: {description}\n"
                formatted_output += f"  Next Action: {next_action}\n"
            else:
                formatted_output += f"- {error}\n"
        return formatted_output.rstrip()

    def _show_file_modifications(
        self,
        start: int,
        end: int,
        original_content: str,
        buffer: str,
        text: str,
    ) -> str:
        """Show file modifications."""
        formatted_output = "\n"

        start_new = max(0, start - 5)
        end_new = min(self.total_lines(), start + len(text.splitlines()) + 5)
        replaced_with = self.format_text(
            {x + 1: buffer.splitlines()[x] for x in range(start_new, end_new)}
        )
        formatted_output += f"How your edit would have looked...\n{replaced_with}\n"

        self.path.write_text(data=original_content, encoding="utf-8")
        start_original = max(0, start - 5)
        end_original = min(self.total_lines(), end + 5)
        replaced_text = self.format_text(
            {
                x + 1: original_content.splitlines()[x]
                for x in range(start_original, end_original)
            }
        )
        formatted_output += f"The original code before your edit...\n{replaced_text}\n"

        formatted_output += (
            "Your changes have not been applied. Fix your edit command and try again.\n"
        )

        return formatted_output.rstrip()

    def _get_error_info(self, error_code: str) -> t.Tuple[str, str]:
        """Get description and next action for a given error code."""
        error_info = {
            "E9": (
                "SyntaxError or IndentationError",
                "Check your syntax and indentation. If you add a newline, make sure the indentation is correct.",
            ),
            "F821": ("Undefined name", "Define the variable before using it"),
            "F823": (
                "Local variable referenced before assignment",
                "Assign a value to the variable before using it",
            ),
            "F831": (
                "Duplicate argument name in function definition",
                "Rename one of the duplicate arguments",
            ),
            "F406": (
                "Module level import not at top of file",
                "Move the import statement to the top of the file",
            ),
            "F407": (
                "Future import should be first non-docstring statement",
                "Move the future import to the top of the file",
            ),
            "F701": (
                "Multiple statements on one line (colon)",
                "Split the statements into separate lines",
            ),
            "F702": (
                "Multiple statements on one line (semicolon)",
                "Split the statements into separate lines",
            ),
            "F704": (
                "Multiple statements on one line (def)",
                "Split the statements into separate lines",
            ),
            "F706": (
                "Multiple statements on one line (lambda)",
                "Split the statements into separate lines",
            ),
            "E999": (
                "SyntaxError",
                "Check your syntax/indentation for errors. If you add a newline, make sure the indentation is correct.",
            ),
            "E902": ("IOError", "Check file permissions and path"),
            "E111": (
                "Indentation is not a multiple of four",
                "Adjust the indentation to be a multiple of four spaces",
            ),
            "E112": ("Expected an indented block", "Add indentation to the block"),
            "E113": ("Unexpected indentation", "Remove unexpected indentation"),
        }
        return error_info.get(
            error_code,
            ("Unknown error", "Review the error message and fix accordingly"),
        )

    def write_and_run_lint(self, text: str, start: int, end: int) -> TextReplacement:
        """Write and run lint on the file. If linting fails, revert the changes."""
        older_file_text = self.path.read_text(encoding="utf-8")
        write_response = self.edit(text=text, start=start, end=end)
        if write_response.get("error"):
            self.path.write_text(data=older_file_text, encoding="utf-8")
            return write_response
        return write_response

    def replace(self, string: str, replacement: str) -> TextReplacement:
        """Replace given string with replacement."""
        content = self.path.read_text(encoding="utf-8")
        update = re.sub(
            pattern=re.escape(string),
            repl=replacement,
            string=content,
        )
        if content == update:
            return {
                "replaced_text": "",
                "replaced_with": "",
                "error": "Error replacing given string, string not found",
            }
        self.path.write_text(update, encoding="utf-8")
        return {"replaced_text": string, "replaced_with": replacement}

    def undo(self) -> t.Optional[str]:
        """Undo the last edit."""
        if not self._history:
            return None
        previous_content = self._history.pop()
        self.path.write_text(previous_content, encoding="utf-8")
        return previous_content

    def __str__(self) -> str:
        """String representation."""
        return f"File(name={self.path})"



from pathlib import Path
from typing import Dict

from pydantic import Field

from composio.tools.base.local import LocalAction
from composio.tools.local.filetool.actions.base_action import (
    BaseFileRequest,
    BaseFileResponse,
    include_cwd,
)


class GitRepoTreeRequest(BaseFileRequest):
    """Request to create a Git repository tree."""

    git_repo_path: str = Field(
        default=".",
        description="Relative path to the git repository. Default is current directory.",
    )


class GitRepoTreeResponse(BaseFileResponse):
    """Response to creating a Git repository tree."""

    success: bool = Field(False, description="Whether the tree creation was successful")
    message: str = Field("", description="Status message or error description")


def git_tree_cmd(repo_path: str) -> str:
    """Command for creating git tree."""
    return f"git -C {repo_path} ls-tree -r HEAD --name-only > {repo_path}/git_repo_tree.txt"


class GitRepoTree(LocalAction[GitRepoTreeRequest, GitRepoTreeResponse]):
    """
    Creates a tree representation of the Git repository.

    This action generates a text file containing the tree structure of the
    current Git repository. It lists all files tracked by Git in the repository.

    Usage example:
        Provide the git_repo_path to generate the repository tree for that specific
        repository. If not provided, it will use the current directory.

    Raises:
        RuntimeError: If there's an issue with the Git command execution or if not in a Git repository.
    """

    @include_cwd  # type: ignore
    def execute(
        self, request: GitRepoTreeRequest, metadata: Dict
    ) -> GitRepoTreeResponse:
        file_manager = self.filemanagers.get(request.file_manager_id)
        repo_path = Path(file_manager.working_dir) / request.git_repo_path
        if not (repo_path / ".git").is_dir():
            return GitRepoTreeResponse(
                success=False,
                message=f"Error: The directory '{repo_path}' is not the root of a git repository.",
            )

        original_dir = file_manager.working_dir
        file_manager.chdir(repo_path)
        command = git_tree_cmd(str(repo_path))
        output, error = file_manager.execute_command(command)
        if error:
            return GitRepoTreeResponse(success=False, error=error, message=output)

        tree_file_path = repo_path / "git_repo_tree.txt"
        if not tree_file_path.exists():
            return GitRepoTreeResponse(
                success=False,
                message="Error: Failed to create git_repo_tree.txt file.",
            )

        try:
            with open(tree_file_path, "r", encoding="utf-8") as f:
                tree_content = f.read()
        except IOError as e:
            return GitRepoTreeResponse(
                success=False, message=f"Error reading git_repo_tree.txt: {str(e)}"
            )

        if not tree_content.strip():
            return GitRepoTreeResponse(
                success=False, message="The repository tree is empty."
            )

        # Change back to the original directory
        file_manager.chdir(original_dir)
        return GitRepoTreeResponse(
            success=True,
            message=(
                "Git repository tree has been generated successfully. "
                "Check git_repo_tree.txt in the repository root for the results."
            ),
        )



"""Tool for executing shell commands."""

import typing as t

from pydantic import BaseModel, Field

from composio.tools.base.local import LocalAction
from composio.tools.env.constants import STDERR, STDOUT
from composio.tools.local.shelltool.shell_exec.actions.exec import ShellRequest


class TestExecRequest(ShellRequest):
    """Test execution request."""


class TestExecResponse(BaseModel):
    """Shell execution response."""

    test_response: str = Field(
        ...,
        description="Response from the test command",
    )
    current_shell_pwd: str = Field(
        default="",
        description="Current shell's working directory",
    )


class TestCommand(LocalAction[TestExecRequest, TestExecResponse]):
    """
    Run the command for testing the patch.
    """

    _tags = ["workspace", "shell"]

    def execute(self, request: TestExecRequest, metadata: t.Dict) -> TestExecResponse:
        """Execute a shell command."""
        shell = self.shells.get(id=request.shell_id)
        project_path = metadata.get("project_path")
        command = metadata.get("test_command")
        self.logger.debug(f"Executing {command} @ {shell}")
        shell.exec(cmd=f"cd {project_path}")
        shell.exec(cmd="python -m pip install -e .")
        output = shell.exec(cmd=f"{command}")
        self.logger.debug(output)
        return TestExecResponse(
            test_response=output[STDERR],
            current_shell_pwd=f"Currently in {shell.exec(cmd='pwd')[STDOUT].strip()}",
        )



"""Composio version helpers."""

import os
import threading

import requests
import rich
from semver import VersionInfo


COMPOSIO_PYPI_METADATA = "https://pypi.org/pypi/composio-core/json"

_latest_version = None


def _fetch_latest_version():
    global _latest_version
    request = requests.get(COMPOSIO_PYPI_METADATA, timeout=10.0)
    if request.status_code != 200:
        return

    data = request.json()
    _latest_version = data["info"]["version"]


def create_latest_version_warning_hook(version: str):
    version_thread = threading.Thread(target=_fetch_latest_version, daemon=True)
    version_thread.start()

    def latest_version_warning() -> None:
        try:
            if (
                os.environ.get("COMPOSIO_DISABLE_VERSION_CHECK", "false").lower()
                == "true"
            ):
                return

            version_thread.join(timeout=0.1)
            if _latest_version is None:
                return

            current_version = VersionInfo.parse(version)
            latest_version = VersionInfo.parse(_latest_version)

            # TODO: Change this to `major` after
            if current_version.minor < latest_version.minor:
                rich.print(
                    "\n[yellow]* A new major version of composio is available, "
                    f"run `pip install composio-core=={latest_version}` "
                    "to update.[/yellow]"
                )
        except Exception:  # pylint: disable=broad-except
            pass

    return latest_version_warning



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class AddTaskToListRequest(BaseModel):
    """Request schema for `AddTaskToList`"""

    list_id: int = Field(
        ...,
        alias="list_id",
        description="",
    )
    task_id: str = Field(
        ...,
        alias="task_id",
        description="",
    )


class AddTaskToListResponse(BaseModel):
    """Response schema for `AddTaskToList`"""

    data: t.Dict[str, t.Any]


class AddTaskToList(OpenAPIAction):
    """
    Add a task to an additional List.    ***Note:** This endpoint requires the
    [Tasks in Multiple List ClickApp](https://help.clickup.com/hc/en-us/articles/6309958824727-Tasks-in-Multiple-Lists)
    to be enabled.*
    """

    _tags = ["Lists"]
    _display_name = "add_task_to_list"
    _request_schema = AddTaskToListRequest
    _response_schema = AddTaskToListResponse

    url = "https://api.clickup.com/api/v2"
    path = "/list/{list_id}/task/{task_id}"
    method = "post"
    operation_id = "Lists_addTaskToList"
    action_identifier = "/list/{list_id}/task/{task_id}_post"

    path_params = {"list_id": "list_id", "task_id": "task_id"}
    query_params = {}
    header_params = {}
    request_params = {}

    aliases = {}



import base64
import platform
import re
import shlex
import shutil
import subprocess
import time
import typing as t
from enum import Enum
from pathlib import Path
from typing import Dict, TypedDict
from uuid import uuid4

from pydantic import BaseModel, Field

from composio.tools.base.exceptions import ExecutionFailed
from composio.tools.base.local import LocalAction


class ActionType(Enum):
    KEY = "key"
    TYPE = "type"
    MOUSE_MOVE = "mouse_move"
    LEFT_CLICK = "left_click"
    LEFT_CLICK_DRAG = "left_click_drag"
    RIGHT_CLICK = "right_click"
    MIDDLE_CLICK = "middle_click"
    DOUBLE_CLICK = "double_click"
    SCREENSHOT = "screenshot"
    CURSOR_POSITION = "cursor_position"


class Resolution(TypedDict):
    width: int
    height: int


MAX_SCALING_TARGETS: dict[str, Resolution] = {
    "XGA": Resolution(width=1024, height=768),  # 4:3
    "WXGA": Resolution(width=1280, height=800),  # 16:10
    "FWXGA": Resolution(width=1366, height=768),  # ~16:9
}


class ScalingSource(str, Enum):
    API = "api"
    COMPUTER = "computer"


class ComputerRequest(BaseModel):
    action: ActionType = Field(
        ...,
        description="The action to perform on the computer",
    )
    text: t.Optional[str] = Field(
        default=None,
        description="Text to type or key sequence to press",
    )
    coordinate: t.Optional[tuple[int, int]] = Field(
        default=None,
        description="X,Y coordinates for mouse actions",
    )


class ComputerResponse(BaseModel):
    response_data: str = Field(
        ...,
        description="Result after executing the action",
    )
    base64_image: t.Optional[str] = Field(
        None,
        description="Base64 encoded screenshot if applicable",
    )


class Computer(LocalAction[ComputerRequest, ComputerResponse]):
    """
    A tool that allows interaction with the screen, keyboard, and mouse of the current computer.
    Adapted for macOS and Linux.
    """

    _tags = ["computer", "mouse", "keyboard", "screenshot"]
    _screenshot_delay = 2.0
    _scaling_enabled = True
    _typing_delay_ms = 12
    _typing_group_size = 50

    def __init__(self):
        super().__init__()
        self.os = platform.system()
        self.width, self.height = self.get_screen_size()
        self.mouse_tool = self._get_mouse_tool()
        self.screenshot_tool = self._get_screenshot_tool()

    def _get_mouse_tool(self):
        if self.os == "Darwin":
            return shutil.which("cliclick")
        if self.os == "Linux":
            return shutil.which("xdotool")
        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def _get_screenshot_tool(self):
        if self.os == "Darwin":
            return "screencapture"
        if self.os == "Linux":
            return "import"
        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def execute(self, request: ComputerRequest, metadata: Dict) -> ComputerResponse:
        act = request.action.value
        if act in ("mouse_move", "left_click_drag"):
            if request.coordinate is None:
                raise ValueError(f"coordinate is required for {act}")

            x, y = self.scale_coordinates(ScalingSource.API, *request.coordinate)
            if act == "mouse_move":
                cmd = self._get_mouse_move_cmd(x, y)
            else:
                current_x, current_y = self.get_mouse_position()
                cmd = self._get_mouse_drag_cmd(int(current_x), int(current_y), x, y)

            result = self.shell(cmd)
            return ComputerResponse(
                response_data=result.response_data or "",
                base64_image=result.base64_image,
            )

        if act in ("key", "type"):
            if request.text is None:
                raise ExecutionFailed(message=f"Text is required for {act}")

            if request.coordinate is not None:
                raise ExecutionFailed(
                    message=(
                        f"coordinate is not accepted for {act}, "
                        f"if you want to perform this action at {request.coordinate} "
                        "use mouse_move and right_click to move the cursor."
                    )
                )

            if act == "key":
                key_sequence = self.map_keys(request.text)
                cmd = self._get_key_press_cmd(key_sequence)
                return self.shell(cmd)

            results = []
            for chunk in self.chunks(request.text, self._typing_group_size):
                cmd = f"{self.mouse_tool} -w {self._typing_delay_ms} t:{shlex.quote(chunk)}"
                results.append(self.shell(cmd, take_screenshot=False))

            return ComputerResponse(
                response_data="".join(r.response_data or "" for r in results),
                base64_image=self.screenshot().base64_image,
            )

        if act in (
            "left_click",
            "right_click",
            "double_click",
            "middle_click",
            "screenshot",
            "cursor_position",
        ):
            if request.coordinate is not None:
                raise ExecutionFailed(
                    message=(
                        f"coordinate is not accepted for {act}, "
                        f"if you want to perform this action at {request.coordinate} "
                        "use mouse_move and right_click to move the cursor."
                    )
                )

            if act == "screenshot":
                result = self.screenshot()
                return ComputerResponse(
                    response_data="Screenshot taken",
                    base64_image=result.base64_image,
                )

            if act == "cursor_position":
                x, y = self.get_mouse_position()
                x, y = self.scale_coordinates(ScalingSource.COMPUTER, int(x), int(y))
                return ComputerResponse(
                    response_data=f"X={x},Y={y}",
                    base64_image=None,
                )

            cmd = self._get_click_cmd(act)
            result = self.shell(cmd)
            return ComputerResponse(
                response_data=result.response_data or "",
                base64_image=result.base64_image,
            )

        raise ValueError(f"Invalid action: {act}")

    def get_screen_size(self):
        """Get the screen size using OS-specific commands."""
        try:
            if self.os == "Darwin":
                cmd = "system_profiler SPDisplaysDataType | grep Resolution"
                output = subprocess.check_output(cmd, shell=True).decode()
                (resolution_line, *_) = output.strip().split("\n", maxsplit=1)
                _, resolution = resolution_line.split(": ", 1)
                match = re.search(r"(\d+)\s*x\s*(\d+)", resolution)
                if match:
                    width_str, height_str = match.groups()
                    return int(width_str), int(height_str)
            elif self.os == "Linux":

                output = subprocess.check_output(["xrandr"]).decode()
                for line in output.split("\n"):
                    if " connected" in line:
                        mode = line.split()[-1]
                        width, height = map(int, mode.split("x"))
                        return width, height

            # If we reach here, we couldn't get the screen size
            raise ValueError("Could not determine screen size")
        except Exception as e:
            print(f"Error getting screen size: {e}")
            return 1920, 1080  # Return a default resolution

    def get_mouse_position(self):
        """Get current mouse position using pyautogui."""
        import pyautogui  # pylint: disable=import-outside-toplevel

        x, y = pyautogui.position()
        return x, y

    def _get_mouse_move_cmd(self, x: int, y: int) -> str:
        if self.os == "Darwin":
            return f"{self.mouse_tool} m:{x},{y}"
        if self.os == "Linux":
            return f"xdotool mousemove {x} {y}"
        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def _get_mouse_drag_cmd(
        self,
        start_x: int,
        start_y: int,
        end_x: int,
        end_y: int,
    ) -> str:
        if self.os == "Darwin":
            return f"{self.mouse_tool} dd:{start_x},{start_y} du:{end_x},{end_y}"
        if self.os == "Linux":
            return f"xdotool mousemove {start_x} {start_y} mousedown 1 mousemove {end_x} {end_y} mouseup 1"
        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def _get_key_press_cmd(self, key_sequence: str) -> str:
        if self.os == "Darwin":
            return f"{self.mouse_tool} kp:{key_sequence}"
        if self.os == "Linux":
            return f"xdotool key {key_sequence}"
        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def _get_click_cmd(self, action: str) -> str:
        if self.os == "Darwin":
            click_arg = {
                "left_click": "c:.",
                "right_click": "rc:.",
                "middle_click": "mc:.",
                "double_click": "dc:.",
            }[action]
            return f"{self.mouse_tool} {click_arg}"

        if self.os == "Linux":
            click_arg = {
                "left_click": "click 1",
                "right_click": "click 3",
                "middle_click": "click 2",
                "double_click": "click --repeat 2 1",
            }[action]
            return f"xdotool {click_arg}"

        raise NotImplementedError(f"Unsupported OS: {self.os}")

    def scale_coordinates(self, source: ScalingSource, x: int, y: int):
        """Scale coordinates to a target maximum resolution."""
        if not self._scaling_enabled:
            return x, y
        ratio = self.width / self.height
        target_dimension = None
        for dimension in MAX_SCALING_TARGETS.values():
            if abs(dimension["width"] / dimension["height"] - ratio) < 0.02:
                if dimension["width"] < self.width:
                    target_dimension = dimension
                break
        if target_dimension is None:
            return x, y

        x_scaling_factor = target_dimension["width"] / self.width
        y_scaling_factor = target_dimension["height"] / self.height

        if source == ScalingSource.API:
            if x > self.width or y > self.height:
                raise ValueError(f"Coordinates {x}, {y} are out of bounds")
            return round(x / x_scaling_factor), round(y / y_scaling_factor)
        return round(x * x_scaling_factor), round(y * y_scaling_factor)

    def map_keys(self, text: str):
        """Map text to cliclick key codes if necessary."""
        return text

    @staticmethod
    def chunks(s: str, chunk_size: int) -> list[str]:
        """Split string into chunks of specified size."""
        return [
            s[i : i + chunk_size] for i in range(0, len(s), chunk_size)  # noqa: E203
        ]

    def screenshot(self):
        """Take a screenshot and return base64 encoded image."""
        output_dir = Path("/tmp/outputs")
        output_dir.mkdir(parents=True, exist_ok=True)
        path = output_dir / f"screenshot_{uuid4().hex}.png"
        if self.os == "Darwin":
            screenshot_cmd = f"screencapture -x {path}"
        elif self.os == "Linux":
            screenshot_cmd = f"import -window root {path}"
        else:
            raise NotImplementedError(f"Unsupported OS: {self.os}")

        result = self.shell(screenshot_cmd, take_screenshot=False)
        if path.exists():
            base64_image = base64.b64encode(path.read_bytes()).decode()
            return ComputerResponse(
                response_data="Screenshot taken",
                base64_image=base64_image,
            )
        raise ValueError(f"Failed to take screenshot: {result.response_data}")

    def shell(self, command: str, take_screenshot=True):
        """Run shell command and return result with optional screenshot."""
        proc = subprocess.run(
            shlex.split(command),
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            check=True,
        )
        base64_image = None
        if take_screenshot:
            time.sleep(self._screenshot_delay)
            screenshot = self.screenshot()
            base64_image = screenshot.base64_image

        return ComputerResponse(
            response_data=proc.stdout.decode() + proc.stderr.decode(),
            base64_image=base64_image,
        )



from typing import Type

from composio.tools.base.local import LocalAction, LocalTool

from .actions.sql_query import SqlQuery


class Sqltool(LocalTool, autoload=True):
    """
    This class enables us to execute sql queries in a database
    """

    logo = "https://raw.githubusercontent.com/ComposioHQ/composio/master/python/docs/imgs/logos/sqltool.png"

    @classmethod
    def actions(cls) -> list[Type[LocalAction]]:
        return [SqlQuery]



"""
Composio CLI Tool.
"""

import typing as t

import click

from composio import __version__
from composio.cli.actions import _actions
from composio.cli.add import _add
from composio.cli.apps import _apps
from composio.cli.connections import _connections
from composio.cli.execute import _execute
from composio.cli.integrations import _integrations
from composio.cli.login import _login
from composio.cli.logout import _logout
from composio.cli.serve import _serve
from composio.cli.triggers import _triggers
from composio.cli.utils.params import EnumParam
from composio.cli.whoami import _whoami
from composio.core.cls.catch_all_exceptions import CatchAllExceptions, handle_exceptions
from composio.core.cls.did_you_mean import DYMGroup
from composio.utils import logging


class HelpDYMGroup(DYMGroup):
    def format_help(self, ctx, formatter):
        formatter.write("\n")

        super().format_help(ctx, formatter)

        formatter.write("\n📙 Examples:\n\n")

        formatter.write(
            click.style("composio --help", fg="green")
            + click.style("          # Display help information\n", fg="black")
        )
        formatter.write(
            click.style("composio add github", fg="green")
            + click.style("      # Add an integration to your account\n", fg="black")
        )
        formatter.write(
            click.style("composio login", fg="green")
            + click.style("           # Log in to your Composio account\n", fg="black")
        )


@click.group(
    name="composio",
    cls=CatchAllExceptions(
        HelpDYMGroup,
        handler=handle_exceptions,
    ),
)
@click.help_option(
    "-h",
    "-help",
    "--help",
)
@click.version_option(
    version=__version__,
)
@click.option(
    "-v",
    "level",
    help="Specify logging verbosity level.",
    type=EnumParam(cls=logging.LogLevel),
)
def composio(level: t.Optional[logging.LogLevel] = None) -> None:
    """
    🔗 Composio CLI Tool.
    """
    if level is not None:
        logging.setup(level=level)


composio.add_command(_add)
composio.add_command(_apps)
composio.add_command(_login)
composio.add_command(_logout)
composio.add_command(_whoami)
composio.add_command(_actions)
composio.add_command(_triggers)
composio.add_command(_integrations)
composio.add_command(_connections)
composio.add_command(_execute)
composio.add_command(_serve)



from typing import Dict

from pydantic import Field, field_validator

from composio.tools.base.local import LocalAction
from composio.tools.local.filetool.actions.base_action import (
    BaseFileRequest,
    BaseFileResponse,
    include_cwd,
)


class CreateFileRequest(BaseFileRequest):
    """Request to create a file or directory."""

    path: str = Field(
        ...,
        description="""Path to create in the editor.
        If file/directory already exists, it will be overwritten""",
    )
    is_directory: bool = Field(
        False,
        description="Whether to create a directory instead of a file",
    )

    @field_validator("path")
    @classmethod
    def validate_path(cls, v: str) -> str:
        if v.strip() == "":
            raise ValueError("Path cannot be empty or just whitespace")
        if v in (".", ".."):
            raise ValueError('Path cannot be "." or ".."')
        return v


class CreateFileResponse(BaseFileResponse):
    """Response to create a file or directory."""

    path: str = Field(
        default=None,
        description="Path of the created file or directory.",
    )


class CreateFile(LocalAction[CreateFileRequest, CreateFileResponse]):
    """
    Creates a new file or directory within a shell session.
    Example:
        - To create a file or directory, provide the path of the new file/directory. If the path you provide
        is relative, it will be created relative to the current working directory.
        - Specify is_directory=True to create a directory instead of a file.
        - The response will indicate whether the file/directory was created successfully and list any errors.
    Raises:
        - ValueError: If the path is not a string or if the path is empty.
        - FileExistsError: If the file/directory already exists.
        - PermissionError: If the user does not have permission to create the file/directory.
        - FileNotFoundError: If the parent directory does not exist.
        - OSError: If an OS-specific error occurs.
    """

    @include_cwd  # type: ignore
    def execute(self, request: CreateFileRequest, metadata: Dict) -> CreateFileResponse:
        if request.is_directory:
            return CreateFileResponse(
                path=str(
                    self.filemanagers.get(
                        request.file_manager_id,
                    ).create_directory(
                        path=request.path,
                    )
                ),
            )

        return CreateFileResponse(
            path=str(
                self.filemanagers.get(request.file_manager_id)
                .create(path=request.path)
                .path
            )
        )



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class GetAccessibleCustomFieldsRequest(BaseModel):
    """Request schema for `GetAccessibleCustomFields`"""

    list_id: int = Field(
        ...,
        alias="list_id",
        description="",
    )


class GetAccessibleCustomFieldsResponse(BaseModel):
    """Response schema for `GetAccessibleCustomFields`"""

    data: t.Dict[str, t.Any]


class GetAccessibleCustomFields(OpenAPIAction):
    """View the Custom Fields available on tasks in a specific List."""

    _tags = ["Custom Fields"]
    _display_name = "get_accessible_custom_fields"
    _request_schema = GetAccessibleCustomFieldsRequest
    _response_schema = GetAccessibleCustomFieldsResponse

    url = "https://api.clickup.com/api/v2"
    path = "/list/{list_id}/field"
    method = "get"
    operation_id = "CustomFields_getListFields"
    action_identifier = "/list/{list_id}/field_get"

    path_params = {"list_id": "list_id"}
    query_params = {}
    header_params = {}
    request_params = {}

    aliases = {}



import os
from typing import Dict, List

from pydantic import BaseModel, Field

from composio.tools.base.local import LocalAction
from composio.tools.local.codeanalysis.actions.base_action import BaseCodeAnalysisAction
from composio.tools.local.codeanalysis.actions.create_codemap import (
    CreateCodeMap,
    CreateCodeMapRequest,
)


class GetClassInfoRequest(BaseModel):
    class_name: str = Field(
        ..., description="Name of the class for which information is requested"
    )


class GetClassInfoResponse(BaseModel):
    result: str = Field(
        ...,
        description="Formatted string containing detailed information about the requested class",
    )


class GetClassInfo(
    LocalAction[GetClassInfoRequest, GetClassInfoResponse], BaseCodeAnalysisAction
):
    """
    This tool retrieves and formats detailed information about a specified class in a given repository.

    Use this action when you need to:
    1. Obtain details about structure, methods and attributes of a specific class in the codebase.
    2. Get the class summary, class variables, instance variables, member functions, and property variables.

    Usage example:
    class_name: Signal

    Note: If multiple classes match the provided name, information for all matching classes will be returned.
    """

    display_name = "Get Class Info"
    _tags = ["index"]

    def execute(
        self, request: GetClassInfoRequest, metadata: Dict
    ) -> GetClassInfoResponse:
        CreateCodeMap().execute(CreateCodeMapRequest(), metadata)
        repo_name = os.path.basename(metadata["dir_to_index_path"])

        self.load_fqdn_cache(repo_name)
        query_class_name = request.class_name

        matching_fqdns = self.get_matching_items(query_class_name, "class")
        class_results = self.get_item_results(
            matching_fqdns=matching_fqdns,
            repo_path=metadata["dir_to_index_path"],
        )

        if not class_results:
            return GetClassInfoResponse(result="No matching results found!")

        result_str = self.format_class_results(class_results)
        return GetClassInfoResponse(result=result_str)

    def format_class_results(self, class_results: List[Dict]) -> str:
        result_str = f"<Total {len(class_results)} result(s) found:>\n"
        for _idx, _class in enumerate(class_results):
            result_str += f"## Details about shortlisted result ID {_idx}:\n"
            result_str += _class["res_fetch_class_stuff"]
            result_str += "\n"
        return result_str



import typing as t

from pydantic import BaseModel, Field

from composio.tools.local.clickup.actions.base import OpenAPIAction


class DeleteSpaceRequest(BaseModel):
    """Request schema for `DeleteSpace`"""

    space_id: int = Field(
        ...,
        alias="space_id",
        description="",
    )


class DeleteSpaceResponse(BaseModel):
    """Response schema for `DeleteSpace`"""

    data: t.Dict[str, t.Any]


class DeleteSpace(OpenAPIAction):
    """Delete a Space from your Workspace."""

    _tags = ["Spaces"]
    _display_name = "delete_space"
    _request_schema = DeleteSpaceRequest
    _response_schema = DeleteSpaceResponse

    url = "https://api.clickup.com/api/v2"
    path = "/space/{space_id}"
    method = "delete"
    operation_id = "Spaces_removeSpace"
    action_identifier = "/space/{space_id}_delete"

    path_params = {"space_id": "space_id"}
    query_params = {}
    header_params = {}
    request_params = {}

    aliases = {}



from composio.tools.local.base import Tool

from .actions.add_dependency import AddDependency
from .actions.add_guest_to_folder import AddGuestToFolder
from .actions.add_guest_to_list import AddGuestToList
from .actions.add_guest_to_task import AddGuestToTask
from .actions.add_tag_to_task import AddTagToTask
from .actions.add_tags_from_time_entries import AddTagsFromTimeEntries
from .actions.add_task_link import AddTaskLink
from .actions.add_task_to_list import AddTaskToList
from .actions.change_tag_names_from_time_entries import ChangeTagNamesFromTimeEntries
from .actions.create_a_time_entry import CreateATimeEntry
from .actions.create_chat_view_comment import CreateChatViewComment
from .actions.create_checklist import (
    CreateChecklist,
    task_checklists_create_new_checklist,
)
from .actions.create_checklist_item import CreateChecklistItem
from .actions.create_folder import CreateFolder, folders_create_new_folder
from .actions.create_folder_view import CreateFolderView
from .actions.create_folderless_list import CreateFolderlessList
from .actions.create_goal import CreateGoal
from .actions.create_key_result import CreateKeyResult
from .actions.create_list import CreateList
from .actions.create_list_comment import CreateListComment
from .actions.create_list_view import CreateListView
from .actions.create_space import CreateSpace
from .actions.create_space_tag import CreateSpaceTag
from .actions.create_space_view import CreateSpaceView
from .actions.create_task import CreateTask
from .actions.create_task_attachment import (
    CreateTaskAttachment,
    attachments_upload_file_to_task_as_attachment,
)
from .actions.create_task_comment import CreateTaskComment
from .actions.create_task_from_template import CreateTaskFromTemplate
from .actions.create_team import CreateTeam, teams_user_groups_create_team
from .actions.create_webhook import CreateWebhook
from .actions.create_workspace_everything_level_view import (
    CreateWorkspaceEverythingLevelView,
)
from .actions.delete_a_time_entry import DeleteATimeEntry
from .actions.delete_checklist import DeleteChecklist
from .actions.delete_checklist_item import DeleteChecklistItem
from .actions.delete_comment import DeleteComment
from .actions.delete_dependency import DeleteDependency
from .actions.delete_folder import DeleteFolder
from .actions.delete_goal import DeleteGoal
from .actions.delete_key_result import DeleteKeyResult
from .actions.delete_list import DeleteList
from .actions.delete_space import DeleteSpace
from .actions.delete_space_tag import DeleteSpaceTag
from .actions.delete_task import DeleteTask
from .actions.delete_task_link import DeleteTaskLink
from .actions.delete_team import DeleteTeam
from .actions.delete_time_tracked import DeleteTimeTracked
from .actions.delete_view import DeleteView
from .actions.delete_webhook import DeleteWebhook
from .actions.edit_checklist import EditChecklist
from .actions.edit_checklist_item import EditChecklistItem
from .actions.edit_guest_on_workspace import EditGuestOnWorkspace
from .actions.edit_key_result import EditKeyResult
from .actions.edit_space_tag import EditSpaceTag
from .actions.edit_time_tracked import EditTimeTracked
from .actions.edit_user_on_workspace import EditUserOnWorkspace
from .actions.get_access_token import GetAccessToken, authorization_get_access_token
from .actions.get_accessible_custom_fields import GetAccessibleCustomFields
from .actions.get_all_tags_from_time_entries import GetAllTagsFromTimeEntries
from .actions.get_authorized_teams_workspaces import (
    GetAuthorizedTeamsWorkspaces,
    authorization_get_work_space_list,
)
from .actions.get_authorized_user import (
    GetAuthorizedUser,
    authorization_view_account_details,
)
from .actions.get_bulk_tasks_time_in_status import GetBulkTasksTimeInStatus
from .actions.get_chat_view_comments import GetChatViewComments
from .actions.get_custom_roles import GetCustomRoles
from .actions.get_custom_task_types import GetCustomTaskTypes
from .actions.get_filtered_team_tasks import GetFilteredTeamTasks
from .actions.get_folder import GetFolder, folders_get_folder_content
from .actions.get_folder_views import GetFolderViews
from .actions.get_folderless_lists import GetFolderlessLists
from .actions.get_folders import GetFolders, folders_get_contents_of
from .actions.get_goal import GetGoal
from .actions.get_goals import GetGoals
from .actions.get_guest import GetGuest
from .actions.get_list import GetList
from .actions.get_list_comments import GetListComments
from .actions.get_list_members import GetListMembers, members_get_list_users
from .actions.get_list_views import GetListViews
from .actions.get_lists import GetLists, lists_get_folder_lists
from .actions.get_running_time_entry import GetRunningTimeEntry
from .actions.get_singular_time_entry import GetSingularTimeEntry
from .actions.get_space import GetSpace, spaces_get_details
from .actions.get_space_tags import GetSpaceTags
from .actions.get_space_views import GetSpaceViews, views_space_views_get
from .actions.get_spaces import GetSpaces, spaces_get_space_details
from .actions.get_task import GetTask, tasks_get_task_details
from .actions.get_task_comments import GetTaskComments
from .actions.get_task_members import GetTaskMembers
from .actions.get_task_s_time_in_status import GetTaskSTimeInStatus
from .actions.get_task_templates import GetTaskTemplates
from .actions.get_tasks import GetTasks, tasks_get_list_tasks
from .actions.get_teams import GetTeams
from .actions.get_time_entries_within_a_date_range import GetTimeEntriesWithinADateRange
from .actions.get_time_entry_history import GetTimeEntryHistory
from .actions.get_tracked_time import GetTrackedTime
from .actions.get_user import GetUser
from .actions.get_view import GetView
from .actions.get_view_tasks import GetViewTasks
from .actions.get_webhooks import GetWebhooks
from .actions.get_workspace_everything_level_views import (
    GetWorkspaceEverythingLevelViews,
    views_get_everything_level,
)
from .actions.get_workspace_plan import (
    GetWorkspacePlan,
    teams_work_spaces_get_work_space_plan,
)
from .actions.get_workspace_seats import (
    GetWorkspaceSeats,
    teams_work_spaces_get_work_space_seats,
)
from .actions.invite_guest_to_workspace import InviteGuestToWorkspace
from .actions.invite_user_to_workspace import InviteUserToWorkspace
from .actions.remove_custom_field_value import RemoveCustomFieldValue
from .actions.remove_guest_from_folder import RemoveGuestFromFolder
from .actions.remove_guest_from_list import RemoveGuestFromList
from .actions.remove_guest_from_task import RemoveGuestFromTask
from .actions.remove_guest_from_workspace import RemoveGuestFromWorkspace
from .actions.remove_tag_from_task import RemoveTagFromTask
from .actions.remove_tags_from_time_entries import RemoveTagsFromTimeEntries
from .actions.remove_task_from_list import RemoveTaskFromList
from .actions.remove_user_from_workspace import RemoveUserFromWorkspace
from .actions.set_custom_field_value import SetCustomFieldValue
from .actions.shared_hierarchy import SharedHierarchy
from .actions.start_a_time_entry import StartATimeEntry
from .actions.stop_a_time_entry import StopATimeEntry
from .actions.track_time import TrackTime
from .actions.update_a_time_entry import UpdateATimeEntry
from .actions.update_comment import UpdateComment
from .actions.update_folder import UpdateFolder
from .actions.update_goal import UpdateGoal
from .actions.update_list import UpdateList
from .actions.update_space import UpdateSpace
from .actions.update_task import UpdateTask
from .actions.update_team import UpdateTeam
from .actions.update_view import UpdateView
from .actions.update_webhook import UpdateWebhook


class ClickupLocal(Tool):
    def actions(self) -> list:
        return [
            CreateTaskAttachment,
            attachments_upload_file_to_task_as_attachment,
            GetAccessToken,
            authorization_get_access_token,
            GetAuthorizedUser,
            authorization_view_account_details,
            GetAuthorizedTeamsWorkspaces,
            authorization_get_work_space_list,
            CreateChecklist,
            task_checklists_create_new_checklist,
            EditChecklist,
            DeleteChecklist,
            CreateChecklistItem,
            EditChecklistItem,
            DeleteChecklistItem,
            GetTaskComments,
            CreateTaskComment,
            GetChatViewComments,
            CreateChatViewComment,
            GetListComments,
            CreateListComment,
            UpdateComment,
            DeleteComment,
            GetAccessibleCustomFields,
            SetCustomFieldValue,
            RemoveCustomFieldValue,
            AddDependency,
            DeleteDependency,
            AddTaskLink,
            DeleteTaskLink,
            GetFolders,
            folders_get_contents_of,
            CreateFolder,
            folders_create_new_folder,
            GetFolder,
            folders_get_folder_content,
            UpdateFolder,
            DeleteFolder,
            GetGoals,
            CreateGoal,
            GetGoal,
            UpdateGoal,
            DeleteGoal,
            CreateKeyResult,
            EditKeyResult,
            DeleteKeyResult,
            InviteGuestToWorkspace,
            GetGuest,
            EditGuestOnWorkspace,
            RemoveGuestFromWorkspace,
            AddGuestToTask,
            RemoveGuestFromTask,
            AddGuestToList,
            RemoveGuestFromList,
            AddGuestToFolder,
            RemoveGuestFromFolder,
            GetLists,
            lists_get_folder_lists,
            CreateList,
            GetFolderlessLists,
            CreateFolderlessList,
            GetList,
            UpdateList,
            DeleteList,
            AddTaskToList,
            RemoveTaskFromList,
            GetTaskMembers,
            GetListMembers,
            members_get_list_users,
            GetCustomRoles,
            SharedHierarchy,
            GetSpaces,
            spaces_get_space_details,
            CreateSpace,
            GetSpace,
            spaces_get_details,
            UpdateSpace,
            DeleteSpace,
            GetSpaceTags,
            CreateSpaceTag,
            EditSpaceTag,
            DeleteSpaceTag,
            AddTagToTask,
            RemoveTagFromTask,
            GetTasks,
            tasks_get_list_tasks,
            CreateTask,
            GetTask,
            tasks_get_task_details,
            UpdateTask,
            DeleteTask,
            GetFilteredTeamTasks,
            GetTaskSTimeInStatus,
            GetBulkTasksTimeInStatus,
            GetTaskTemplates,
            CreateTaskFromTemplate,
            GetWorkspaceSeats,
            teams_work_spaces_get_work_space_seats,
            GetWorkspacePlan,
            teams_work_spaces_get_work_space_plan,
            CreateTeam,
            teams_user_groups_create_team,
            GetCustomTaskTypes,
            UpdateTeam,
            DeleteTeam,
            GetTeams,
            GetTrackedTime,
            TrackTime,
            EditTimeTracked,
            DeleteTimeTracked,
            GetTimeEntriesWithinADateRange,
            CreateATimeEntry,
            GetSingularTimeEntry,
            DeleteATimeEntry,
            UpdateATimeEntry,
            GetTimeEntryHistory,
            GetRunningTimeEntry,
            RemoveTagsFromTimeEntries,
            GetAllTagsFromTimeEntries,
            AddTagsFromTimeEntries,
            ChangeTagNamesFromTimeEntries,
            StartATimeEntry,
            StopATimeEntry,
            InviteUserToWorkspace,
            GetUser,
            EditUserOnWorkspace,
            RemoveUserFromWorkspace,
            GetWorkspaceEverythingLevelViews,
            views_get_everything_level,
            CreateWorkspaceEverythingLevelView,
            GetSpaceViews,
            views_space_views_get,
            CreateSpaceView,
            GetFolderViews,
            CreateFolderView,
            GetListViews,
            CreateListView,
            GetView,
            UpdateView,
            DeleteView,
            GetViewTasks,
            GetWebhooks,
            CreateWebhook,
            UpdateWebhook,
            DeleteWebhook,
        ]

    def triggers(self) -> list:
        return []
